package PAR::StrippedPARL::Dynamic;
use 5.006;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See L<http://www.perl.com/perl/misc/Artistic.html>

=cut



__DATA__
M?T5,1@$!`0````````````(``P`!````,)8$"#0````XK@```````#0`(``(
M`"@`'``;``8````T````-(`$"#2`!`@``0````$```4````$`````P```#0!
M```T@00(-($$"!,````3````!`````$````!``````````"`!`@`@`0(9*H`
M`&2J```%`````!````$```!DJ@``9#H%"&0Z!0B0`@``W!(```8`````$```
M`@```'BJ``!X.@4(>#H%"!@!```8`0``!@````0````$````2`$``$B!!`A(
M@00(1````$0````$````!````%#E=&1,I0``3"4%"$PE!0C,````S`````0`
M```$````4>5T9```````````````````````````!@````0````O;&EB+VQD
M+6QI;G5X+G-O+C(```0````0`````0```$=.50```````@````8````@````
M!````!0````#````1TY5`#)UM]QV<'UI_X?,G%Z?`&I"J)/6`P```%`````$
M````!P```$``"`#`((`).`X(`8$$A`A0````50```%H```#(U;)QIMVC:\2)
M!9"ZXY)\0T75[*Q+X\!Z\$IKV'%8',2YG$"YC?$.ZM/O#H;YG('SV],=````
M`````````````````#P#`````````````!(```"R```````````````2````
MTP,`````````````$@```+X#`````````````!(```"H`0`````````````2
M`````P0`````````````$@```($"`````````````!(````,````````````
M```@````&P``````````````(````,0#`````````````!(```"4`0``````
M```````2````)`0`````````````$@```'4!`````````````!(```"'`0``
M```````````2````8`0`````````````$@```&P#`````````````!(````;
M`P`````````````2````,P(`````````````$@```/X``````````````!(`
M```C`@`````````````2````Z`,`````````````$@```-$!````````````
M`!(```"5!``````````````2````4P0`````````````$@```"@#````````
M`````!(````C`P`````````````2````GP(`````````````$@```/$!````
M`````````!(```"M`0`````````````2````/`(`````````````$@```!$$
M`````````````!(```"'!``````````````2````,`$`````````````$@``
M`!P$`````````````!(````O```````````````2````+@0`````````````
M$@```&0!`````````````!(```#)```````````````2````9P0`````````
M````$@```/P#`````````````!(```!,!``````````````2````X0,`````
M````````$@```+<#`````````````!(```"4`P`````````````2````0@$`
M````````````$@```#P$`````````````!(```!C`@`````````````2````
MG0,`````````````$@```$T#`````````````!(```!5`@`````````````2
M````[P,`````````````$@```)@"`````````````!(```"R`0``````````
M```2````I@,`````````````$@```/8#`````````````!(```#:`P``````
M```````2````[0``````````````$@```#T``````````````!(```!#!```
M```````````2````?P0`````````````$@```-@``````````````!(````%
M`@`````````````2````C`(`````````````$@```%<!`````````````!(`
M``!Q!``````````````2````S`,`````````````$@```(,#````````````
M`!(````4`P`````````````2````'@$`````````````$@```$H"````````
M`````!(```!/```````````````2````WP$`````````````$@```&0`````
M`````````!(```".!``````````````2````D```````````````$@```(L#
M`````````````!(```!^`P`````````````2````>0``````````````$@``
M``P!`````````````!(```"^`0``A)$$"``````2````J00````]!0@$````
M(0`9`*@$````/04(!````"$`&0#$!```0$T%"``````0`/'_L00``/0\!0@`
M````$`#Q_UT#``"DQ@0(!````!$`#P!Q`@``5),$"``````2````N`0``/0\
M!0@`````$`#Q_Z<$````/04(!````!$`&0!>````U)`$"``````2``L`40$`
M`&S&!`@`````$@`.`*$```!DDP0(`````!(```"J`@``!#T%"!,````1`!D`
M`&QI8G!E<FPN<V\`7U]G;6]N7W-T87)T7U\`7TIV7U)E9VES=&5R0VQA<W-E
M<P!097)L7W-Y<U]T97)M`%!E<FQ?27-T871B=69?<'1R`%!E<FQ?<WES7VEN
M:70S`%]I;FET`%!E<FQ?265X:71?9FQA9W-?<'1R`%!E<FQ?<V%V95]D97-T
M<G5C=&]R7W@`4&5R;%])8V]M<&-V7W!T<@!097)L7V%T9F]R:U]L;V-K`%!E
M<FQ?26-U<G-T86-K:6YF;U]P='(`<&5R;%]C;VYS=')U8W0`4&5R;%]C<F]A
M:U]N;V-O;G1E>'0`4&5R;%])<&%R<V5R7W!T<@!097)L7V%V7W-H:69T`%!E
M<FQ?<W9?,G!V7V9L86=S`%!E<FQ?271O<%]E;G9?<'1R`%!E<FQ?271A:6YT
M961?<'1R`%!E<FQ?<W9?<V5T<'9N`%]F:6YI`%!E<FQ?;F5W4U9P=@!097)L
M7VYE=UA37V9L86=S`%!E<FQ?26EN7V5V86Q?<'1R`%!E<FQ?26]P7W!T<@!0
M97)L7TEE=F%L7W)O;W1?<'1R`'!E<FQ?9G)E90!097)L7VUG7W-E=`!097)L
M7V%T9F]R:U]U;FQO8VL`4&5R;%]S=E]S971P=@!097)L7T=T:')?:V5Y7W!T
M<@!097)L7T=D;U]U;F1U;7!?<'1R`%!E<FQ?27!E<FQ?9&5S=')U8W1?;&5V
M96Q?<'1R`%!E<FQ?9W9?9F5T8VAP=@!P97)L7W)U;@!097)L7V1O=6YW:6YD
M`%!E<FQ?;F5W6%,`<&5R;%]D97-T<G5C=`!097)L7V%V7V9E=&-H`&)O;W1?
M1'EN84QO861E<@!P97)L7W!A<G-E`%!E<FQ?<V%F97-Y<VUA;&QO8P!P97)L
M7V%L;&]C`%!,7VUE;6]R>5]W<F%P`&QI8G)E<V]L=BYS;RXR`&QI8FYS;"YS
M;RXQ`&QI8F1L+G-O+C(`;&EB;2YS;RXV`&QI8F-R>7!T+G-O+C$`;&EB=71I
M;"YS;RXQ`&QI8G!T:')E860N<V\N,`!O<&5N-C0`;'-E96LV-`!R96%D`'!T
M:')E861?9V5T<W!E8VEF:6,`7U]E<G)N;U]L;V-A=&EO;@!C;&]S90!L:6)C
M+G-O+C8`7TE/7W-T9&EN7W5S960`7U]R96=I<W1E<E]A=&9O<FL`97AI=`!S
M=')N8VUP`%]?<W1R9'5P`&=E='!W=6ED`&-L;W-E9&ER`%]?<W1A8VM?8VAK
M7V9A:6P`=6YL:6YK`&UK9&ER`')E86QL;V,`;65M8VAR`&=E='!I9`!S=')T
M;VL`<W1R;&5N`&UE;7-E=`!S=')S='(`<FUD:7(`;65M8W!Y`%]?<W1R;F-P
M>5]C:&L`7U]L>'-T870V-`!O<&5N9&ER`%]?>'-T870V-`!?7V-T>7!E7V)?
M;&]C`&=E='5I9`!R96%D;&EN:P!E>&5C=G``7U]M96UC<'E?8VAK`'-T<F-H
M<@!R96%D9&ER-C0`7U]S<')I;G1F7V-H:P!M96UM;W9E`&%C8V5S<P!S=')C
M;7``7U]L:6)C7W-T87)T7VUA:6X`7U]E;G9I<F]N`%]E9&%T80!?7V)S<U]S
M=&%R=`!?96YD`"]U<W(O;&EB+W!E<FPU+T-/4D4`1TQ)0D-?,BXT`$=,24)#
M7S(N,P!'3$E"0U\R+C,N,@!'3$E"0U\R+C(`1TQ)0D-?,BXS+C0`1TQ)0D-?
M,BXP``````(````#``,````$``````````,````%```````#``8`!P``````
M```#`````P`$``(``@```````P````4``P````,````(```````%``,``P`#
M``,``P````,````#``(````#``,````)``,``P```````P`#````````````
M!``#``,`!P```````````````P````,``P`````````#``,``0`!``$````!
M``,``0`!```````!``8`4P,``!````!P````%&EI#0``"0#=!```$````!-I
M:0T```@`YP0``!````!R&6D)```&`/$$```0````$FEI#0``!0#]!```$```
M`'09:0D```0`!P4``!`````0:6D-```#`!,%`````````0`"``0#```0````
M`````!)I:0T```<`_00``!`````0:6D-```"`!,%````````D#L%"`8(````
M/04(!5@```0]!0@%7```H#L%"`<!``"D.P4(!P(``*@[!0@'`P``K#L%"`<$
M``"P.P4(!P4``+0[!0@'!@``N#L%"`<'``"\.P4(!U```,`[!0@'"```Q#L%
M"`<*``#(.P4(!PL``,P[!0@'#```T#L%"`<-``#4.P4(!PX``-@[!0@'#P``
MW#L%"`<0``#@.P4(!Q$``.0[!0@'$@``Z#L%"`<3``#L.P4(!Q0``/`[!0@'
M%0``]#L%"`<6``#X.P4(!Q<``/P[!0@'&````#P%"`<9```$/`4(!QH```@\
M!0@'&P``##P%"`<<```0/`4(!QT``!0\!0@''@``&#P%"`<?```</`4(!R``
M`"`\!0@'(0``)#P%"`<B```H/`4(!R,``"P\!0@')```,#P%"`=6```T/`4(
M!UL``#@\!0@')0``/#P%"`<F``!`/`4(!R<``$0\!0@'*```2#P%"`<I``!,
M/`4(!RH``%`\!0@'*P``5#P%"`<L``!8/`4(!RT``%P\!0@'+@``8#P%"`<O
M``!D/`4(!S```&@\!0@',0``;#P%"`<R``!P/`4(!S,``'0\!0@'-```>#P%
M"`<U``!\/`4(!S8``(`\!0@'-P``A#P%"`<X``"(/`4(!SD``(P\!0@'.@``
MD#P%"`<[``"4/`4(!SP``)@\!0@'/0``G#P%"`<^``"@/`4(!S\``*0\!0@'
M0```J#P%"`=!``"L/`4(!T(``+`\!0@'0P``M#P%"`=$``"X/`4(!T4``+P\
M!0@'1@``P#P%"`='``#$/`4(!T@``,@\!0@'20``S#P%"`=*``#0/`4(!TL`
M`-0\!0@'3```V#P%"`=-``#</`4(!TX``.`\!0@'3P``58GE4X/L!.@`````
M6X'#M*H``(N3_/___X72=`7HG@```.C%!0``Z$`U``!86\G#_S68.P4(_R6<
M.P4(`````/\EH#L%"&@`````Z>#_____):0[!0AH"````.G0_____R6H.P4(
M:!````#IP/____\EK#L%"&@8````Z;#_____);`[!0AH(````.F@_____R6T
M.P4(:"@```#ID/____\EN#L%"&@P````Z8#_____);P[!0AH.````.EP____
M_R7`.P4(:$````#I8/____\EQ#L%"&A(````Z5#_____)<@[!0AH4````.E`
M_____R7,.P4(:%@```#I,/____\ET#L%"&A@````Z2#_____)=0[!0AH:```
M`.D0_____R78.P4(:'````#I`/____\EW#L%"&AX````Z?#^____)>`[!0AH
M@````.G@_O___R7D.P4(:(@```#IT/[___\EZ#L%"&B0````Z<#^____)>P[
M!0AHF````.FP_O___R7P.P4(:*````#IH/[___\E]#L%"&BH````Z9#^____
M)?@[!0AHL````.F`_O___R7\.P4(:+@```#I</[___\E`#P%"&C`````Z6#^
M____)00\!0AHR````.E0_O___R4(/`4(:-````#I0/[___\E##P%"&C8````
MZ3#^____)1`\!0AHX````.D@_O___R44/`4(:.@```#I$/[___\E&#P%"&CP
M````Z0#^____)1P\!0AH^````.GP_?___R4@/`4(:``!``#IX/W___\E)#P%
M"&@(`0``Z=#]____)2@\!0AH$`$``.G`_?___R4L/`4(:!@!``#IL/W___\E
M,#P%"&@@`0``Z:#]____)30\!0AH*`$``.F0_?___R4X/`4(:#`!``#I@/W_
M__\E/#P%"&@X`0``Z7#]____)4`\!0AH0`$``.E@_?___R5$/`4(:$@!``#I
M4/W___\E2#P%"&A0`0``Z4#]____)4P\!0AH6`$``.DP_?___R50/`4(:&`!
M``#I(/W___\E5#P%"&AH`0``Z1#]____)5@\!0AH<`$``.D`_?___R5</`4(
M:'@!``#I\/S___\E8#P%"&B``0``Z>#\____)60\!0AHB`$``.G0_/___R5H
M/`4(:)`!``#IP/S___\E;#P%"&B8`0``Z;#\____)7`\!0AHH`$``.F@_/__
M_R5T/`4(:*@!``#ID/S___\E>#P%"&BP`0``Z8#\____)7P\!0AHN`$``.EP
M_/___R6`/`4(:,`!``#I8/S___\EA#P%"&C(`0``Z5#\____)8@\!0AHT`$`
M`.E`_/___R6,/`4(:-@!``#I,/S___\ED#P%"&C@`0``Z2#\____)90\!0AH
MZ`$``.D0_/___R68/`4(:/`!``#I`/S___\EG#P%"&CX`0``Z?#[____):`\
M!0AH``(``.G@^____R6D/`4(:`@"``#IT/O___\EJ#P%"&@0`@``Z<#[____
M):P\!0AH&`(``.FP^____R6P/`4(:"`"``#IH/O___\EM#P%"&@H`@``Z9#[
M____);@\!0AH,`(``.F`^____R6\/`4(:#@"``#I</O___\EP#P%"&A``@``
MZ6#[____)<0\!0AH2`(``.E0^____R7(/`4(:%`"``#I0/O___\ES#P%"&A8
M`@``Z3#[____)=`\!0AH8`(``.D@^____R74/`4(:&@"``#I$/O___\EV#P%
M"&AP`@``Z0#[____)=P\!0AH>`(``.GP^O___R7@/`4(:(`"``#IX/K__P``
M`````````````#'M7HGA@^3P4%12:##&!`AHT,4$"%%6:'##!`CH(_S___20
MD)"0D)"0D)"0D)"0D%6)Y5.-9"3\@#T8/04(`'4^NW`Z!0BA'#T%"('K;#H%
M",'[`H/K`3G8<QV0C70F`(U``:,</04(_Q2%;#H%"*$</04(.=ARZ,8%&#T%
M"`&-9"0$6UW#C78`C;PG`````%6)Y8UD).BA=#H%"(7`=!*X`````(7`=`G'
M!"1T.@4(_]#)PY"0D)"0D)"0D)"0D%6)Y5=6C8VT_O__4XG#C:0DH/[__X/#
M'(F%K/[__S'`BQ2##\J)%(&-0`&#^!!U\(V5Z/[__XU-Z(VT)@````"+0NPS
M`C-"U#-"S,'('XE"#(U2!#G*=>B+E:S^__^+A:S^__^+M:S^__^+C:S^__^+
MG:S^__^+4@2+`(F5I/[__XMV$(N5M/[__XF%J/[__P'RBTD(P<`%B8V@_O__
MBUL,B;68_O__B[6D_O__B9V<_O__P<8>B[V@_O__C8P"F7F"6HN%I/[___?0
MBY6@_O__(=@CE:3^__\)T(N5N/[__P'!`=J+A:C^__^+G:C^__\A\_?0(X6@
M_O__`[V\_O__"=B+G:C^___!PQZ-E`*9>8):B<C!P`4!PHG0P<`%C80'F7F"
M6HF%E/[__XG(B<_WT"'?(?`#M<#^__\)^`.%E/[__XFUE/[__XG6P<$>B=?W
MUB'/(=X#G<3^__\)_HN]E/[__\'"'HVT-YEY@EJ)M;#^__^)QL'&!0.UL/[_
M_XGWP<<%C;P[F7F"6HG#B;V4_O__]].)QR'+(=<)^P.=E/[__P.-R/[__XGW
MB8V4_O__B?'!P![WT2''(=$)^8N]E/[__P.5S/[__\'&'HV,#YEY@EJ)C;#^
M__^)V<'!!0.-L/[__XG/P<<%C;PZF7F"6HG:B;V4_O__]]*)WR'"(?<#A=#^
M__\)^@.5E/[__XF%E/[__XG(P<,>B<_WT"'?(?`#M=3^__\)^(N]E/[__\'!
M'HV$!YEY@EJ)A;#^__^)T(N]L/[__\'`!0''B?C!P`6-A`:9>8):B864_O__
MB=")UO?0(<XAV`.=V/[__PGP`X64_O__B9V4_O__B?O!PAZ)_O?3(=8ARPGS
MB[64_O__`XW<_O__P<<>C9P>F7F"6HF=L/[__XG#P<,%`YVP_O__B=[!Q@6-
MM#&9>8):B<&)M93^___WT8G&(=$A_@.5X/[__PGQ`XV4_O__B964_O__B=K!
MP!Z)WO?2(<8A^@.]Y/[__PGRB[64_O__P<,>C906F7F"6HF5L/[__XG*B[6P
M_O__P<(%`=:)\L'"!8V4%YEY@EJ)E93^__^)RHG/]](AWR'"`X7H_O__"?H#
ME93^__^)A93^__^)\,'!'HGW]]`ASR'8`YWL_O__"?B+O93^___!QAZ-A`>9
M>8):B86P_O__B="+O;#^___!P`4!QXGXP<`%C80#F7F"6HF%E/[__XG0B=/W
MT"'S(<@#C?#^__\)V`.%E/[__XF-E/[__XGYP<(>B?OWT2'3(?$#M?3^__\)
MV8N=E/[__\'''HV,"YEY@EJ)C;#^__^)P8N=L/[__\'!!0'+B=G!P06-C`Z9
M>8):B8V4_O__B<&)QO?1(?XAT0.5^/[__PGQ`XV4_O__B964_O__B=K!P!Z)
MWO?2(<8A^@.]_/[__PGRB[64_O__P<,>C906F7F"6HF5L/[__XG*B[6P_O__
MP<(%`=:)\L'"!8V4%YEY@EJ)E93^__^)RHG/]](AWR'""?H#E93^___!P1X#
MA0#___^)A93^__^)\(GW]]`ASR'8"?B+O93^___!QAX#G03___^-A`>9>8):
MB?<QSXF%L/[__S'7B=#!P`4#A;#^___!PAX#C0C___^-O#NAZ]ENB</!PP4!
M^XG7,?<#M0S___\QQ\'`'HV\.:'KV6Z)V<'!!0'YB<<QUP.5$/___S'?P<,>
MC;P^H>O9;HG.P<8%`?Z)WS''`X44____,<_!P1Z-O#JAZ]ENB?+!P@4!^HG/
M,=\#G1C___\Q]\'&'HV\.*'KV6Z)T,'`!0''B?`QR`.-'/___S'0P<(>C9P#
MH>O9;HGXP<`%`=B)TS'S`[4@____,?O!QQZ-G!FAZ]ENB<'!P04!RXGY,=$#
ME23___\QP<'`'HVT#J'KV6Z)V<'!!0'QB<8Q_@.]*/___S'>P<,>C;0RH>O9
M;HG*P<(%`=:)VC'",<J-O!>AZ]ENB?+!P@4!^@.%+/___\'!'HG/,=\#G3#_
M__\Q]\'&'HV\.*'KV6Z)T,'`!0''B?`QR`.--/___S'0P<(>C9P#H>O9;HGX
MP<`%`=B)TS'S`[4X____,?O!QQZ-G!FAZ]ENB<'!P04!RXGY,=$#E3S___\Q
MP<'`'HVT#J'KV6Z)V<'!!0'QB<8Q_@.]0/___S'>P<,>C;0RH>O9;HG*P<(%
M`=:)VC'"`X5$____,<K!P1Z-O!>AZ]ENB?+!P@4!^HG/,=\#G4C___\Q]\'&
M'HV\.*'KV6Z)T,'`!0''B?`QR`.-3/___S'0P<(>C9P#H>O9;HGXP<`%`=B)
MTS'S`[50____,?O!QQZ-G!FAZ]ENB<'!P04!V8G[,=,#E53___\QPXF5E/[_
M_\'`'HG"(?J-M!ZAZ]ENB<O!PP4!\XG&"?XAS@G6BY64_O__P<$>`[U8____
MB;V4_O__B<\AQXVT,MR\&X^)VL'"!0'RB<X)Q@.%7/___R'>"?Z+O93^___!
MPQZ)A93^__^)V"'(C;0WW+P;CXG?"<^)M;#^__\AUXG6"<>+A93^___!Q@4#
MM;#^___!PAX#C6#___^)C93^__^)T8V\.-R\&X^)\,'`!2'9`?B)UPG?`YUD
M____(?<)SXN-E/[__\'&'HF=E/[__XGS(=.-O#G<O!N/B<'!P04!^8GW"=<A
MQPG?BYV4_O__C;P[W+P;CXG+P<,%`Y5H____P<`>`?N)QXF5E/[__PGWB<(A
M\B'/"=>+E93^___!P1X#M6S___^)M93^__^)SB'&C;PZW+P;CXG:P<(%`?J)
MSPG'`X5P____(=\)]XNUE/[__\'#'HF%E/[__XG8(<B-O#[<O!N/B=;!Q@4!
M_HG?"<\#C73___\AUPG'BX64_O__P<(>B8V4_O__B=$AV8V\.-R\&X^)\,'`
M!0'XB=<)WR'W"<^+C93^__^-O#G<O!N/B<'!P04!^0.=>/___\'&'HF=E/[_
M_XGWB?,)UR'3(<<#E7S___\)WXN=E/[__\'`'HF5E/[__XG"(?*-O#O<O!N/
MB<O!PP4!^XG'"?<#=8`ASPG7BY64_O__P<$>B;64_O__B<XAQHV\.MR\&X^)
MVL'"!0'ZB<\)QP-%A"'?"?>+M93^___!PQZ)A93^__^)V"'(C;P^W+P;CXG6
MP<8%`?Z)WPG/(=<)QXN%E/[__XV\.-R\&X^)\,'`!0'XP<(>`TV(B=>)C93^
M__\)WXG1(=DA]PG/BXV4_O__P<8>`UV,B9V4_O__B?,ATXV\.=R\&X^)P<'!
M!0'YB?<)UP-5D"''"=^+G93^___!P!Z)E93^__^)PB'RC;P[W+P;CXG+P<,%
M`?N)QPGW`W64(<\)UXN5E/[__\'!'HFUE/[__XG.(<:-O#K<O!N/B=K!P@4!
M^HG/"<<AWPGWB[64_O__P<,>C;P^W+P;CXG6P<8%`?X#19B)WXF%E/[__PG/
MB=@AR"'7"<>+A93^___!PAX#39R)C93^__^)T2'9C;PXW+P;CXGPP<`%`?B)
MUPG?`UV@(?<)SXN-E/[__\'&'HF=E/[__XGS(=.-O#G<O!N/B<'!P04!SXGQ
M"=$#5:0AP0G9BYV4_O__P<`>C8P+W+P;CXG#,?.)C;#^__\Q^XGYP<$%`XVP
M_O__P<<>`W6HC9P:UL%BRHG*P<(%`=.)^C'",<J-M!;6P6+*B=K!P@4#1:S!
MP1X!\HG.,?X#?;`QWL'#'HVT,-;!8LJ)T,'`!0'&B=@QR`--M#'0P<(>C;P'
MUL%BRHGPP<`%`?B)US'?`UVX,??!QAZ-O#G6P6+*B<'!P04!SXGQ,=$#5;PQ
MP<'`'HV<"];!8LJ)^<'!!0'9B<,Q\S'[P<<>C9P:UL%BRHG*P<(%`=.)^@-U
MP#'",<H#1<3!P1Z-M!;6P6+*B=K!P@4!\HG.,?X#?<@QWL'#'HVT,-;!8LJ)
MT,'`!0'&B=@QR`--S#'0P<(>C;P'UL%BRHGPP<`%`?B)US'?`UW0,??!QAZ-
MO#G6P6+*B<'!P04!SXGQ,=$#5=0QP<'`'HV<"];!8LJ)^<'!!0'9B<,Q\S'[
MC9P:UL%BRHG*P<(%`W78P<<>`=.)^C'"`T7<,<K!P1Z-M!;6P6+*B=K!P@4!
M\HG.,?X#?>`QWL'#'HVT,-;!8LJ)T,'`!0'&B=@QR`--Y#'0P<(>C;P'UL%B
MRHGPP<`%`?B)US'?`UWH,??!QAZ-O#G6P6+*B<'!P04!^8GW,=<QQ\'`'HV\
M.];!8LJ)R\'#!0'[B<<#5>PQ]S'/P<$>C;PZUL%BRHG:P<(%`=>+E:C^__\#
M5?"-M!;6P6+*B<HQPC':`?*)_L'&!0'RB[6L_O__P<,>B18#O:3^__\#G:#^
M__\#C9S^__\#A9C^__^)?@2)7@B)3@R)1A"-I"1@`0``6UY?7<.-="8`C;PG
M`````%6)Y8UD),B)7?2)PS'`A=N)=?B)??R)5=QU#8M=](MU^(M]_(GL7<.+
M%0`]!0B%THE5X'3F#[8#/#UT!(3`=4@QTHM%X(LP,<"%]G3.B5WDBWW@B=.-
M=@"+5>2)7"0(B50D!(DT).@)\?__A<!U!H`\'CUT*XU_!(LWA?9UVC'`ZYF-
MM@````")VHU2`0^V`CP]=`2$P'7R*=KKIHUT)@"+1=PK?>#!_P*).(U$'@'I
M9____XVV`````(V_`````%6)Y8UD).B-5?3H,?___\G#ZPV0D)"0D)"0D)"0
MD)"058GE5HG&4XGPC5WTC60D\(G:Z`G___^%P'0ND(UT)@"+1?3!X`(#!0`]
M!0B-="8`C4`$BQ"%THE0_'7TB=J)\.C;_O__A<!UUXUD)!!;7EW#ZPV0D)"0
MD)"0D)"0D)"058GE5E.-9"3PQP0D`````.AO\/__BP")!"3H5>W__XD$).C=
MZ___BP"+<`3'!"0`````Z$SP__^+`(D$).@R[?__B00DZ&KL__\/MAC'!"0`
M````@^-_Z"CP__^+`(D$).@.[?__B00DZ%;L__^+``^W0!#!X`<)V&:)1@+'
M!"0`````Z/OO__^+`(D$).CA[/__B00DZ&GK__^+`(M8!,<$)`````#HV.__
M_XL`B00DZ+[L__^)!"3'1"0(`````,=$)`1ZR`0(Z#;O__^)0QS'!"0`````
MZ*?O__^+`(D$).B-[/__B00DZ!7K__^+`(M8!,<$)`````#HA.___XL`B00D
MZ&KL__^)!"3H@NO__XL`B4,@QP0D`````.AA[___BP")!"3H1^S__XD$).C/
MZO__BP"+6`3'!"0`````Z#[O__^+`(D$).@D[/__B00DZ#SN__^+`#'2A<!T
M(\<$)`````#H&.___XL`B00DZ/[K__^)!"3H%N[__XL`BU!LB5,DQP0D````
M`.CR[O__BP")!"3HV.O__XD$).A@ZO__BP"+0`3'0"@`````QP0D`````.C(
M[O__BP")!"3HKNO__XD$).@VZO__BP"+0`3'0!@`````QP0D`````.B>[O__
MBP")!"3HA.O__XD$).@,ZO__BP"+6`3'!"0`````Z'ON__^+`(D$).AAZ___
MB00DZ#GN__^+`(E#+(UD)!!;7EW#D(VT)@````!5B>57B<=64XVD)&3___^%
MP'0%@#@`=1"-I"2<````6UY?7<.-="8`B00DZ*3K__^%P(G&=.)FD(DT).@$
M[/__A<`/A-````"-6!,/MA6MQ@0(#[9`$SG0=0X/MA6NQ@0(.%,!=-)FD`^V
M%:S&!`@YT`^$P0```(D\).CUZ___B1PDB46`Z.KK__^+58"-1`("B00DZ'OL
M__^)182)7"04B7PD$,=$)`ROQ@0(QT0D"/_____'1"0$`0```(D$).@@[?__
MBU6$C46(B50D!(E$)`C'!"0#````Z);I__^#^/]T#XM%F"4`\```/0!```!T
M;HM%A(D$).B'Z___BU6$B10DZ'SJ__^)-"3H-.O__X7`#X4P____B30DZ+3K
M__^)/"3H'.S__XVD))P```!;7E]=PXUT)@`/M@6MQ@0(.$,!#X4O____#[85
MKL8$"#A3`@^$X/[__^D:____C78`BT6$Z)C^___KDXVV`````%6)Y5:)QE,Q
MVXUD)/#'!"0`````Z,OL__^+`(D$).BQZ?__B00DZ-GK__^)1"0(B70D!,<$
M)`,```#H]>G__X7`=`V-9"00B=A;7EW#C78`QP0D`````.B([/__BP")!"3H
M;NG__XD$).B6Z___BT`0)0#P```]`$```'0MQP0D`````.A;[/__BP")!"3H
M0>G__XD$).AIZ___BT`0)0#P```]`*```'69B30DQT0D!`(```#HBNG__S';
MA<`/E,.-9"00B=A;7EW#D(UT)@!5B>575HG&,<!3B=.-9"3$@#H]#Y3``<.)
M'"3H%.K__XE%U(U5Y(GPZ"/Z__^%P(G'=#6)!"3H^>G__S'2.474#X>$`0``
M9I`/M@03A,"(!!>-4@%U\C'`C60D/%M>7UW#C;0F`````(L5`#T%"#'_N`@`
M``"+"H7)=!:0C70F`(U_`8L$NH7`=?:-!+T(````BPTP/04(A<D/A-D```")
M1"0$B10DZ&GG__^)P:,`/04(A<FX_____W2=C02]`````(E%T,=$N00`````
MB7WD#[8&/#T/A/T```"$P`^$]0```(GPZP60A-)T"XU``0^V$(#Z/77QBU74
M*?"+?=`#/0`]!0B-1`("B00DZ,/I__^)PHD'A=*X_____P^$-O___XM5Y*$`
M/04(BP20#[86A-*($'0>@/H]=!F-=@'K!8#Z/70/#[86C4`!A-*($(UV`77L
MQ@`],=*-M"8`````#[8,$X3)B$P0`8U2`77QZ>+^__^-="8`B57,QP4P/04(
M`0```(D$).A'Z?__B<&+5<R%R;C_____#X2Y_O__C02]`````(D,)(E-S(E%
MT(E$)`B)5"0$Z)CI__^+3<R)#0`]!0CI^_[__XM%Y,'@`HE%T.GX_O__B?#I
M&/___Y!5B>6-9"3HQP0D`````.@AZO__BP")!"3H!^?__XD$),=$)`RUQ@0(
MQT0D"%23!`C'1"0$O\8$".C7Z?__R<.058GEC60DV,<$)`````#HX>G__XL`
MB00DZ,?F__^)!"3HF____\<$)`````#HP^G__XL`B00DZ*GF__^)!"3'1"04
M`````,=$)!!ZR`0(QT0D#'K(!`C'1"0(,+T$",=$)`3;Q@0(Z%GG___)PXUV
M`%6)Y8VD)+C?__]EH10```")1>0QP(E=](EU^(E]_(V=X^___^CKY/__B40D
M$,=$)!2+R`0(QT0D#/#&!`C'1"0(`1```,=$)`0!````B1PDZ+_H__\Q]H7`
M>1V+5>1E,Q44````B?!U5HM=](MU^(M]_(GL7<-FD(D<),=$)`@`$```C;WB
MW___B7PD!.@BZ/__A<")PWC#C4`!B00DZ*'G__^%P(G&=+*)7"0(B7PD!(D$
M).C+YO__Q@0>`.N<Z*#G__^-M@````"-OP````!5B>6-9"3XR>DC____C78`
M58GE5U93C:0DM.___XM="&6A%````(E%Y#'`N/S&!`B+?0SH>/?__\=$)`0O
M````B1PDB874[___Z+;D__^%P'0JB=JX!<<$".A"_/__BU7D93,5%````(G8
M#X6$`0``C:0D3!```%M>7UW#B1PDZ%#F__^)QHD\),=$)`02QP0(Z![G__^%
MP(G'=+:-=@&)M=#O__^-M>3O__^0C70F`(`_`+BMQ@0(#T3XBX74[___A<!T
M&HN5U.___XE\)`2)%"3H_>?__X7`#X3#````B3PDZ.WE__^`?`?_+W409I"-
M0/^`?`?_+\8$!P!T\@.%T.___SW_#P``#X]#____B5PD&,=$)!04QP0(B7PD
M$,=$)`PPR`0(QT0D"``0``#'1"0$`0```(DT).@%Y___QP0D`````.AIY___
MBP")!"3H3^3__XD$).AWYO__B40D"(ET)`3'!"0#````Z&/C__^%P'4MQP0D
M`````.@SY___BP")!"3H&>3__XD$).A!YO__BT`0)0#P```]`(```'0CQT0D
M!!+'!`C'!"0`````Z/[E__^%P(G'#X7P_O__Z8W^___'1"0$`0```(DT).@_
MY/__A<!UR8GRN`7'!`CHN_K__XDT).@'Y___B</I:O[__^B;Y?__C;0F````
M`%6)Y8M%"`^V"(3)=!.-4`&`^2\/M@H/1,*$R8U2`77P7<.-M"8`````C;PG
M`````%6)Y5.-9"3LBUT(A=MT*8`[`'0DB1PDZ(CD__^-1`/_.<-R"^L^9I"-
M0/\YPW,U@#@O=/3K)V:0QP0D`@```.@`Y?__A<!T!6;'`"X`C60D%%M=PXUT
M)@"`."]T!XU`_SG#<O0YV'48@#@O=%O'10@4QP0(C60D%%M=Z47F__^0C4#_
M.<-S!8`X+W3TB<(QP"G:C4H"@?D`$```=["-4@''1"0,`!```(E4)`B)7"0$
MQP0D0#T%".B(X?__N$`]!0CKBI"-="8`QP0D`@```.APY/__B<(QP(72#X1M
M____9L<"+@")T.EA____C70F`%6)Y5=6C60DT&6A%````(E%]#'`H9C(!`B)
M1=*AG,@$"(E%UJ&@R`0(B47:H:3(!`B)1=ZAJ,@$"(E%XJ&LR`0(B47FH;#(
M!`B)1>JAM,@$"(E%[@^W!;C(!`AFB47RN!;'!`CH1_3__[@?QP0(Z#WT__^X
M)\<$".@S]/__N##'!`CH*?3__[@WQP0(Z!_T__^X1\<$".@5]/__N/S&!`CH
M"_3__[A3QP0(Z`'T__^X7<<$".CW\___N&?'!`CH[?/__[@%QP0(Z./S__^X
M<<<$".C9\___N'K'!`CHS_/__[B%QP0(Z*7S__^%P'0,B<*X7<<$".B%^/__
MN);'!`CHB_/__X7`=`R)PKBHQP0(Z&OX__^XL\<$".AQ\___A<!T-8G"N/S&
M!`CH4?C__[K?QP0(N#?'!`CH0OC__XM%]&4S!10```!U3HUD)#!>7UW#C;8`
M````N,/'!`CH+O/__X7`=!*)PKA3QP0(Z`[X___KNXUT)@"-=>._U,<$"+D*
M````\Z9UIHU5[;A3QP0(Z.KW___KE^C7XO__C78`58GEC60D^*'H/`4(@_C_
M=`?)PY"-="8`N%/'!`CHSO+__XG",<"%TG0/#[82A-)T"#'`@/HP#Y7`H^@\
M!0C)PU6)Y8UD).CH".+__XD$).C@X?__B<(QP(72=`*+`LG#58GE5U:-==13
MN^O'!`B-9"2DQT70Z\<$"(M]",=%U.''!`C'1=CNQP0(QT7<Y,<$",=%X.G'
M!`C'1>1ZR`0(ZR2-M"8`````B7PD!(D$)(E%Q.CMX?__A<!T/8L>C78$@#L`
M=".)V.@D\O__A<!T!8`X`'73B=B)^N@"]___BQZ-=@2`.P!UW8UD)%Q;7E]=
MPXVT)@````")/"3H%.'__XM5Q(E%P(D4).@&X?__BTW`C40!`HD$).B7X?__
MBU7$QT0D%!+'!`B)5"08B7PD$,=$)`PPR`0(QT0D"/_____'1"0$`0```(D$
M)(E%P.@QXO__BTW`B=B)RNB!]O__Z5?___^-M@````"-OP````!5B>575E.-
MI"2T?O__BT4(B87X?O__N/S&!`AEBQ44````B57D,=+'A2A___\'R`0(QX4L
M?___#\@$",>%,'___ZW&!`C'A31___]ZR`0(QX40?___J,<$",>%%'___Z''
M!`C'A1A___\4R`0(QX4<?___"L@$",>%('___QS(!`C'A21___]ZR`0(QX4X
M?___^\<$",>%/'___R#(!`C'A4!___]ZR`0(Z-+P__^%P'0)@#@`#X4E`P``
MD(UT)@#H"_[__X7`B<</A#D#```/MA^$VW0BZ$G?__^)^HUV`(L(#[[;]@19
M"'4#Q@)?C5(!#[8:A-MUZ+L!````N*C'!`CK%XUT)@"+A)T0?___C5L!@#@`
M#X1M`@``Z&#P__^%P(G&=.+H=?3__X7`=-F)-"3HC>'__X7`=,V)QHDT).A?
MW___B<.)/"3H5=___XV4`P0$``")%"2)E?1^___HX-___XN5]'[__XG#B10D
MB87\?O__Z,K?__^)A0!___^)?"0<QT0D&"G(!`C'1"04%,<$"(ET)!#'1"0,
M+L@$",=$)`C_____QT0D!`$```")!"3H7.#__XN]`'___\=$)`3M`0``B3PD
MZ%;<__^XY,<$".BH[___A<`/A&@"``")!"3HW.#__XN5^'[__XE$)`2+`HD$
M).CD]___A<")A01___\/A#X"``"+A01___^)!"3HC-[__X/X`WXSBY4$?___
MOS?(!`BY!0```(UT`OSSIG4;@_@$#X2*!@``B[T$?___@'P'^R\/A'D&``"0
MZ#O\__^%P'4DBY4$?___QT0D!`````")%"3HU=___X7`B84$?___#X7C`0``
MNM_'!`BX4\<$".CD\___Z(/;__^+O0!____'1"0<>L@$"(E\)!")1"08QT0D
M%!3'!`C'1"0,5<@$",=$)`C_____QT0D!`$```")'"0Q]NA#W___B[T`?___
MZU6-M"8`````Z`_;__^#.!%U6>@EV___C78!QT0D('K(!`B)="0<B40D&,=$
M)!04QP0(B7PD$,=$)`QCR`0(QT0D"/_____'1"0$`0```(D<).CFWO__QT0D
M!.T!``")'"3HYMK__X/X_W2=BX4`?___B00DZ&/<__^)VKC\Q@0(Z!/S__^)
M'"3HB_O__XM5Y&4S%10```"+A?Q^__\/A8T&``"-I"1,@0``6UY?7<.0B[4H
M?___NP$```"`/@!U%^L_C;8`````B[2=*'___XU;`8`^`'0JB?#HZO'__X7`
M=.:)-"3H`M___X7`#X5Q_?__B[2=*'___XU;`8`^`'76,?;I7?W__XD$)(F%
M]'[__^@"^___BX7T?O__B00DZ,C>__^)A?Q^___I7O___Y"[`0```+C[QP0(
MZQ>-="8`BX2=.'___XU;`8`X``^$[00``.A0[?__A<!TY(D$).B(WO__A<!T
MV(G'Z8C\__^0B[WX?O__BS^)O01____IK_W__Y"-="8`QT0D#`(```#'1"0$
M[O___\=$)`C_____B00DZ'3:__^+A01____'1"0(!@```(V]1'___XD$)(E\
M)`3HY-K__X"]1'___P!U#8"]17___T,/A+L$``"+A01____'1"0,`````,=$
M)`0`````QT0D"`````")!"3H&-K__XV58/___\>%1/___P$C16?'A4C___^)
MJ\WOQX5,_____MRZF,>%4/___W94,A#'A53____PX=+#QX58____`````,>%
M7/___P````#'1:``````B97D?O__B9WX?O__D(UT)@"+A01____'1"0(`(``
M`(V]1'___XD$)(E\)`3H)-K__X7`B<,/CGX!``"+E5C___^-O41___^-!-J)
MA5C___\YT(G8#Y+"#[;2`95<____P>@=`85<____BT6@A<!T6;]`````C95@
M____*<>-!`(Y^XV51'___XD$)(E4)`0/3ON)?"0(Z+K:__^+1:`!^(/X0(E%
MH`^%9?___XV%1'___RG[C3PXC85$____Z-_=__^-M"8`````@_L_#XZ\````
M,?:0C70F`(L$-XF%8/___XM$-P2)A63___^+1#<(B85H____BT0W#(F%;/__
M_XM$-Q")A7#___^+1#<4B85T____BT0W&(F%>/___XM$-QR)A7S___^+1#<@
MB46`BT0W)(E%A(M$-RB)18B+1#<LB46,BT0W,(E%D(M$-S2)192+1#<XB468
MBT0W/(E%G(V%1/___^@VW?__B=B-=D`I\(/X/P^/7O___XU;P(G8P>@&B<+!
MX@8ITXU\.D"-E6#____'1"0,1````(E<)`B)?"0$B10DZ(G8__^)7:#I7?[_
M_Y"-="8`BY4$?___BYWX?O__B10DZ!C:__^+M5C___^+E5S___^)\,'H`X/@
M/\:$!6#___^`@\`!@_@X#X_^`0``N3@```"-O6#___\IP8F5]'[__XT$!XE,
M)`C'1"0$`````(D$).CFU___BY7T?O__B="(59O!Z!B-?:>(19B)T,'H$(A%
MF8G0P>@(B$6:B?#!Z!B(19R)\,'H$(A%G8GPP>@(B$6>B?"(19^-A43____H
M-MS__XN51/___S'VB=&(5=/!Z1B)R(A-T(G1P>D0B$W1B='!Z0B+E4C___^(
M3=*)T<'I&(A5UXA-U(G1P>D0B$W5B='!Z0B+E4S___^(3=:)T<'I&(A5VXA-
MV(G1P>D0B$W9B='!Z0B+E5#___^(3=J)T<'I&(A5WXA-W(G1P>D0B$W=B='!
MZ0B+E53___^(3=Z)T<'I&(A5XXA-X(G1P>D0B$WAB='!Z0B(3>+K"(UV``^V
M1#70#[;`QT0D#%#(!`B)1"00C01WC78!QT0D"/_____'1"0$`0```(D$).B:
MV?__@_X4=<F+E0!____&1<\`QT0D''K(!`B)?"08QT0D%!3'!`B)5"00QT0D
M#$'(!`C'1"0(_____\=$)`0!````B1PDZ%/9___I??K__V:0BX7X?O__BU`$
MA=(/A'?Y__^)%"2)E?1^___HO=?__X/X`XN5]'[__P^&6OG__XUT`OR_/,@$
M"+D%````\Z8/194$?___B94$?___Z3CY__^_`,@$".G6]___N4````"-O6#_
M__\IP8F5]'[__XT$!XE,)`C'1"0$`````(D$).CHU?__C85$____Z'G:__^Y
M#@```#'`B[WD?O__\ZN+E?1^___IX_W__X"]1G___T$/A3C[__^`O4=___]#
M#X4K^___@+U(?___2`^%'OO__X"]27___T4/A1'[__^+E01____'1"0,`@``
M`,=$)`3&____QT0D"/____^)%"3H*=7__XN%!'___XE\)`3'1"0(*0```(D$
M).B?U?__B7PD&(N]`'___\=$)!QZR`0(QT0D%!3'!`B)?"00Z9G^___H5]?_
M_XUV`%6)Y5=64XVD),3O___'!"0`````9:$4````B47D,<#H4-C__XL`B00D
MZ#;5__^)!"3HKM7__\8``;@WQP0(Z"WG__^%P'0)@#@Q#X0H`P``Z(OR___'
M!"0`````Z!/8__^+`(D$).CYU/__B00DQT0D#`L```#'1"0(`0```,=$)`1T
MR`0(Z(G4__^%P`^$W0```(M`##'VBT`8B874[___H2@]!0B#^`$/CK8```"[
M`0```.LQ9I"+1PR+%20]!0B+%)J)1"0$B10DZ,37__^%P`^%B````(U;`:$H
M/04(.=B-=@%^?L<$)`````#H@=?__XL`B00DZ&?4__^+E=3O___'1"0,````
M`(ET)`B)5"0$B00DZ,G5__^%P'1!BSCV1PD$=9''!"0`````Z$'7__^+`(D$
M).@GU/__B00DQT0D#`(```#'1"0(`````(E\)`3HB]?__^E=____9I"A*#T%
M"(U0_SGR#X28`0``QP0D`````.CXUO__BP")!"3HWM/__XD$),=$)`P$````
MQT0D"`$```#'1"0$><@$".ANT___A<")PW0^BT`,BS#'!"0`````Z+?6__^+
M`(D$).B=T___B00DQT0D"'O(!`B)="0$Z%G3__^+0PR+&/9#"D`/A68!``#'
M!"0`````Z'[6__^+`(D$).ADT___B00DQT0D#`0```#'1"0(`0```,=$)`2#
MQP0(Z/32__^%P(G#=#^X!<<$".A`Y?__A<")Q@^$3@$``(M##(LXQP0D````
M`.@IUO__BP")!"3H#]/__XD$)(ET)`B)?"0$Z,_2___'!"0`````Z`/6__^+
M`(D$).CITO__B00DZ&'3___&``#'!"0`````Z.+5__^+`(D$).C(TO__B00D
MZ`#6___'``````"X_,8$".B\Y/__A<"C+#T%"`^$L`$``,=$)`3M`0``B00D
MZ$/1__^#^!%T$(7`=`R#^/^-=@`/A?4!``"+1>1E,P44````#X7@`0``C:0D
M/!```%M>7UW#C;8`````@_@!#XY?_O__NP$```!FD,<$)`````"-6P'H3=7_
M_XL`B00DZ#/2__^+E=3O__^)!"2)5"0$Z,'1__\Y'2@]!0A_S>D@_O__QP0D
M`````.@8U?__BP")!"3H_M'__XD$)(E<)`3HTM/__^ES_O__D(!X`0`/A-/\
M___IR?S__Y"A)#T%"(V]Y.___XL`B870[___BT,,BP#'!"0`````B874[___
MZ,+4__^+`(D$).BHT?__QT0D"/\/``")?"0$QP0D@,@$".C0T___A<")QGY@
MC4#_@+P%Y.___P!U!H7`=$^)QHET)`C'1"0$+P```(D\).@3U/__A<!T-<<$
M)`````#H8]3__XL`B00DZ$G1__^+E=3O__^)="0,B7PD"(E4)`2)!"3HC]+_
M_^DK_O__QP0D`````.@NU/__BP")!"3H%-'__XN5T.___XD$)(E4)`B+E=3O
M__^)5"0$Z,C0___I]/W__Z$D/04(B00DZ'+Q__^C+#T%"(M##(L])#T%"(LP
M]D8)!`^$FP```(M&#(E\)`2)!"3HW='__XG&BT,,BQCV0PD$=$N+0PR)1"0(
MH20]!0B)="0,BP#'!"2\R`0(B40D!.CNTO__Z'G2__^)1"0,H2P]!0B)1"0(
MH20]!0B+`,<$).S(!`B)1"0$Z,72___'!"0`````Z&G3__^+`(D$).A/T/__
MB00DQT0D#`(```#'1"0(`````(E<)`3HL]/__^N$QP0D`````.@UT___BP")
M!"3H&]#__XD$),=$)`P"````QT0D"`````")="0$Z'_3___I,?___XVV````
M`%6)Y593C60D\(MU"(DT).AL[/__#[80B<.$TG03C4`!@/HO#[80#T38A-*-
M0`%U\.C;[O__A<!T'87V=!F`/@!T%,=$)`0IR`0(B1PDZ&+1__\YV'0(C60D
M$%M>7<.-9"00B?!;7EWI1.3__XUT)@!5B>6-9"3HQP0D`````.B!TO__BP")
M!"3H9\___XD$),=$)`3_____Z*?/___'!"0`````Z%O2__^+`(D$).A!S___
MB00DQT0D"`````#'1"0$(*4$".B9TO__R<.-=@!5B>6#Y/!64XU%$(UD),B)
M1"0(C44,B40D!(U%"(D$).C_T?__QT0D"(21!`C'1"0$A)$$",<$)&23!`CH
MWP$``,<$)`````#H!\___X`X`'4[Z.W.__^%P*,@/04(#X2P`0``B00DZ*C/
M___'!"0`````Z+S1__^+`(D$).BBSO__B00DZ`K1___&``#'!"0`````Z)O1
M__^+`(D$).B!SO__B00DZ)G1__^`"`+'!"0`````Z'K1__^+`(D$).A@SO__
MB00DZ'C1__^`"`&+10B#P`4QR8E$)"B)3"0LWVPD*-@%/,D$"-T%0,D$"-G)
MW^G=V`^'!0$``,'@`HD$).B>T/__BW4,HR0]!0B+%L=`!(_(!`B)$,=`"&#)
M!`C'0`R2R`0(BUT(@_L!QP4H/04(!````'X5N@$```!FD(L,EHE,D`R-4@$Y
MVG7RC5L#QP28`````(E$)`RA(#T%"(E<)`C'1"00`````,=$)`2PJP0(B00D
MZ(?,__^%P(G#=#VA(#T%"(D$).A$S___N$?'!`CHEM___X7`=#JA(#T%"(D$
M).@YS/__Z!3.__^-9"0XB=A;7HGL7<.-="8`H2`]!0B)!"3HY\S__XG#Z[*-
MM"8`````H2P]!0B%P'0*B00DZ$?]___KL[C\Q@0(Z#O?__^%P*,L/04(=*#K
MX<=$)`0$/04(QP0D^<8$".APS___QP0D`0```.ADT/__58GE4^@R````@</[
M=0``@^P0BX,4B___B40D#(M%$(E$)`B+10R)1"0$BT4(B00DZ#_,__^#Q!!;
M7<.+'"3#D%6)Y5=64^CP____@<.Y=0``@^P<Z.O*__^-N]#^__^-@]#^__\I
MQ\'_`H7_="0Q]HM%$(E$)`B+10R)1"0$BT4(B00D_Y2ST/[__X/&`3G^<MZ#
MQ!Q;7E]=PXVV`````%6)Y5W#D)"0D)"0D)"0D)!5B>53C60D_*%D.@4(@_C_
M=!*[9#H%")"-6_S_T(L#@_C_=?2-9"0$6UW#D%6)Y5.#[`3H`````%N!PQQU
M``#HW,___UE;R<,````````````````````````````````#`````0`"````
M```N+@`E<R\E<P!P97)L>'-I+F,`1'EN84QO861E<CHZ8F]O=%]$>6YA3&]A
M9&5R`$EN=&5R;F%L<SHZ4$%2.CI"3T]4`"]P<F]C+R5I+R5S`%!!4E]414U0
M`%!!4E]04D]'3D%-10`Z`"\`4$523#5,24(`4$523$Q)0@!015),-4]05`!0
M15),24\`4$%27TE.251)04Q)6D5$`%!!4E]34$%73D5$`%!!4E]#3$5!3@!0
M05)?1$5"54<`4$%27T-!0TA%`%!!4E]!4D=#`%!!4E]!4D=67S``4$%27T=,
M3T)!3%]$14)51P!005)?1TQ/0D%,7U1-4$1)4@!005)?5$U01$E2`%!!4E]'
M3$]"04Q?5$5-4`!005)?1TQ/0D%,7T-,14%.`%!!4E]#3$5!3CT`,0!,24)0
M051(`$193$1?3$E"4D%265]0051(`%5315(`4UE35$5-`$,Z7%1%35``+W1M
M<`!414U01$E2`%1-4`!54T523D%-10!P87(M`"5S)7,E<R5S`'!A<FP`+G!A
M<@`E<R5S8V%C:&4M)7,E<P`E,#)X`"5S)7-T96UP+25U)7,`)7,E<W1E;7`M
M)74M)74E<P!!4D=6`!@`<&5R;``O<')O8R]S96QF+V5X90`M90`M+0````!?
M7T5.5E]005)?0TQ%04Y?7R`@("`@("`@("`@("`@(``````E<SH@97AE8W5T
M:6]N(&]F("5S(&9A:6QE9"`M(&%B;W)T:6YG('=I=&@@)6DN"@`E<SH@8W)E
M871I;VX@;V8@<')I=F%T92!T96UP;W)A<GD@<W5B9&ER96-T;W)Y("5S(&9A
M:6QE9"`M(&%B;W)T:6YG('=I=&@@)6DN"@```````````(#____/07!A<BYP
M;````````````````````````",A+W5S<B]B:6XO<&5R;`IE=F%L("=E>&5C
M("]U<W(O8FEN+W!E<FP@("U3("0P("1[,2LB)$`B?2<*("`@(&EF(#`[(",@
M;F]T(')U;FYI;F<@=6YD97(@<V]M92!S:&5L;`H*<&%C:V%G92!?7W!A<E]P
M;#L*"B,@+2TM(%1H:7,@<V-R:7!T(&UU<W0@;F]T('5S92!A;GD@;6]D=6QE
M<R!A="!C;VUP:6QE('1I;64@+2TM"B,@=7-E('-T<FEC=#L*"B-L:6YE(#$U
M.`H*;7D@*"1P87)?=&5M<"P@)'!R;V=N86UE+"!`=&UP9FEL92D["D5.1"![
M(&EF("@D14Y6>U!!4E]#3$5!3GTI('L*("`@(')E<75I<F4@1FEL93HZ5&5M
M<#L*("`@(')E<75I<F4@1FEL93HZ0F%S96YA;64["B`@("!R97%U:7)E($9I
M;&4Z.E-P96,["B`@("!M>2`D=&]P9&ER(#T@1FEL93HZ0F%S96YA;64Z.F1I
M<FYA;64H)'!A<E]T96UP*3L*("`@(&]U=',H<7%[4F5M;W9I;F<@9FEL97,@
M:6X@(B1P87)?=&5M<")]*3L*("`@($9I;&4Z.D9I;F0Z.F9I;F1D97!T:"AS
M=6(@>R`H("UD("D@/R!R;61I<B`Z('5N;&EN:R!]+"`D<&%R7W1E;7`I.PH@
M("`@<FUD:7(@)'!A<E]T96UP.PH@("`@(R!$;VXG="!R96UO=F4@=&]P9&ER
M(&)E8V%U<V4@=&AI<R!C875S97,@82!R86-E('=I=&@@;W1H97(@87!P<PH@
M("`@(R!T:&%T(&%R92!T<GEI;F<@=&\@<W1A<G0N"@H@("`@:68@*"UD("1P
M87)?=&5M<"`F)B`D7D\@;F4@)TU35VEN,S(G*2!["B`@("`@("`@(R!3;VUE
M=&AI;F<@=V5N="!W<F]N9R!U;FQI;FMI;F<@=&AE('1E;7!O<F%R>2!D:7)E
M8W1O<GDN("!4:&ES"B`@("`@("`@(R!T>7!I8V%L;'D@:&%P<&5N<R!O;B!P
M;&%T9F]R;7,@=&AA="!D:7-A;&QO=R!U;FQI;FMI;F<@<VAA<F5D"B`@("`@
M("`@(R!L:6)R87)I97,@86YD(&5X96-U=&%B;&5S('1H870@87)E(&EN('5S
M92X@56YL:6YK('=I=&@@82!B86-K9W)O=6YD"B`@("`@("`@(R!S:&5L;"!C
M;VUM86YD('-O('1H92!F:6QE<R!A<F4@;F\@;&]N9V5R(&EN('5S92!B>2!T
M:&ES('!R;V-E<W,N"B`@("`@("`@(R!$;VXG="!D;R!A;GET:&EN9R!O;B!7
M:6YD;W=S(&)E8V%U<V4@;W5R('!A<F5N="!P<F]C97-S('=I;&P*("`@("`@
M("`C('1A:V4@8V%R92!O9B!C;&5A;FEN9R!T:&EN9W,@=7`N"@H@("`@("`@
M(&UY("1T;7`@/2!N97<@1FEL93HZ5&5M<"@*("`@("`@("`@("`@5$5-4$Q!
M5$4@/3X@)W1M<%A86%A8)RP*("`@("`@("`@("`@1$E2(#T^($9I;&4Z.D)A
M<V5N86UE.CID:7)N86UE*"1T;W!D:7(I+`H@("`@("`@("`@("!3549&25@@
M/3X@)RYC;60G+`H@("`@("`@("`@("!53DQ)3DL@/3X@,"P*("`@("`@("`I
M.PH*("`@("`@("!P<FEN="`D=&UP("(C(2]B:6XO<V@*>#TQ.R!W:&EL92!;
M(%PD>"`M;'0@,3`@73L@9&\*("`@<FT@+7)F("<D<&%R7W1E;7`G"B`@(&EF
M(%L@7"$@+60@)R1P87)?=&5M<"<@73L@=&AE;@H@("`@("`@8G)E86L*("`@
M9FD*("`@<VQE97`@,0H@("!X/6!E>'!R(%PD>"`K(#%@"F1O;F4*<FT@)R(@
M+B`D=&UP+3YF:6QE;F%M92`N("(G"B(["B`@("`@("`@("`@(&-H;6]D(#`W
M,#`L)'1M<"T^9FEL96YA;64["B`@("`@("`@;7D@)&-M9"`]("1T;7`M/F9I
M;&5N86UE("X@)R`^+V1E=B]N=6QL(#(^)C$@)B<["B`@("`@("`@8VQO<V4@
M)'1M<#L*("`@("`@("!S>7-T96TH)&-M9"D["B`@("`@("`@;W5T<RAQ<2A3
M<&%W;F5D(&)A8VMG<F]U;F0@<')O8V5S<R!T;R!P97)F;W)M(&-L96%N=7`Z
M("D*("`@("`@("`@("`@("X@)'1M<"T^9FEL96YA;64I.PH@("`@?0I]('T*
M"D)%1TE.('L*("`@($EN=&5R;F%L<SHZ4$%2.CI"3T]4*"D@:68@9&5F:6YE
M9"`F26YT97)N86QS.CI005(Z.D)/3U0["@H@("`@979A;"!["@I?<&%R7VEN
M:71?96YV*"D["@II9B`H97AI<W1S("1%3E9[4$%27T%21U9?,'T@86YD("1%
M3E9[4$%27T%21U9?,'T@*2!["B`@("!`05)'5B`](&UA<"`D14Y6>R)005)?
M05)'5E\D7R)]+"`H,2`N+B`D14Y6>U!!4E]!4D=#?2`M(#$I.PH@("`@)#`@
M/2`D14Y6>U!!4E]!4D=67S!].PI]"F5L<V4@>PH@("`@9F]R("AK97ES("5%
M3E8I('L*("`@("`@("!D96QE=&4@)$5.5GLD7WT@:68@+UY005)?05)'5E\O
M.PH@("`@?0I]"@IM>2`D<75I970@/2`A)$5.5GM005)?1$5"54=].PH*(R!F
M:7@@)'!R;V=N86UE(&EF(&EN=F]K960@9G)O;2!0051("FUY("5#;VYF:6<@
M/2`H"B`@("!P871H7W-E<"`@("`]/B`H)%Y/(#U^("]>35-7:6XO(#\@)SLG
M(#H@)SHG*2P*("`@(%]E>&4@("`@("`@(#T^("@D7D\@/7X@+UXH/SI-4U=I
M;GQ/4S)\8WEG=VEN*2\@/R`G+F5X92<@.B`G)RDL"B`@("!?9&5L:6T@("`@
M("`]/B`H)%Y/(#U^("]>35-7:6Y\3U,R+R`_("=<7"<@.B`G+R<I+`HI.PH*
M7W-E=%]P<F]G;F%M92@I.PI?<V5T7W!A<E]T96UP*"D["@HC($UA9VEC('-T
M<FEN9R!C:&5C:VEN9R!A;F0@97AT<F%C=&EN9R!B=6YD;&5D(&UO9'5L97,@
M>WM["FUY("@D<W1A<G1?<&]S+"`D9&%T85]P;W,I.PI["B`@("!L;V-A;"`D
M4TE'>U]?5T%23E]??2`]('-U8B![?3L*"B`@("`C($-H96-K(&9I;&4@='EP
M92P@9V5T('-T87)T(&]F(&1A=&$@<V5C=&EO;B![>WL*("`@(&]P96X@7T9(
M+"`G/"<L("1P<F]G;F%M92!O<B!L87-T.PH@("`@8FEN;6]D92A?1D@I.PH*
M("`@(&UY("1B=68["B`@("!S965K(%]&2"P@+3@L(#(["B`@("!R96%D(%]&
M2"P@)&)U9BP@.#L*("`@(&QA<W0@=6YL97-S("1B=68@97$@(EQN4$%2+G!M
M7&XB.PH*("`@('-E96L@7T9(+"`M,3(L(#(["B`@("!R96%D(%]&2"P@)&)U
M9BP@-#L*("`@('-E96L@7T9(+"`M,3(@+2!U;G!A8VLH(DXB+"`D8G5F*2P@
M,CL*("`@(')E860@7T9(+"`D8G5F+"`T.PH*("`@("1D871A7W!O<R`]("AT
M96QL(%]&2"D@+2`T.PH@("`@(R!]?7T*"B`@("`C($5X=')A8W1I;F<@96%C
M:"!F:6QE(&EN=&\@;65M;W)Y('M[>PH@("`@;7D@)7)E<75I<F5?;&ES=#L*
M("`@('=H:6QE("@D8G5F(&5Q(")&24Q%(BD@>PH@("`@("`@(')E860@7T9(
M+"`D8G5F+"`T.PH@("`@("`@(')E860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB
M+"`D8G5F*3L*"B`@("`@("`@;7D@)&9U;&QN86UE(#T@)&)U9CL*("`@("`@
M("!O=71S*'%Q*%5N<&%C:VEN9R!F:6QE("(D9G5L;&YA;64B+BXN*2D["B`@
M("`@("`@;7D@)&-R8R`]("@@)&9U;&QN86UE(#U^('-\7BA;82UF7&1=>SA]
M*2]\?"`I(#\@)#$@.B!U;F1E9CL*("`@("`@("!M>2`H)&)A<V5N86UE+"`D
M97AT*2`]("@D8G5F(#U^(&U\*#\Z+BHO*3\H+BHI*%PN+BHI?"D["@H@("`@
M("`@(')E860@7T9(+"`D8G5F+"`T.PH@("`@("`@(')E860@7T9(+"`D8G5F
M+"!U;G!A8VLH(DXB+"`D8G5F*3L*"B`@("`@("`@:68@*&1E9FEN960H)&5X
M="D@86YD("1E>'0@(7X@+UPN*#\Z<&U\<&Q\:7A\86PI)"]I*2!["B`@("`@
M("`@("`@(&UY("@D;W5T+"`D9FEL96YA;64I(#T@7W1E;7!F:6QE*"1E>'0L
M("1C<F,I.PH@("`@("`@("`@("!I9B`H)&]U="D@>PH@("`@("`@("`@("`@
M("`@8FEN;6]D92@D;W5T*3L*("`@("`@("`@("`@("`@('!R:6YT("1O=70@
M)&)U9CL*("`@("`@("`@("`@("`@(&-L;W-E("1O=70["B`@("`@("`@("`@
M("`@("!C:&UO9"`P-S4U+"`D9FEL96YA;64["B`@("`@("`@("`@('T*("`@
M("`@("`@("`@)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD9G5L;&YA;65](#T@
M)&9I;&5N86UE.PH@("`@("`@("`@("`D4$%2.CI(96%V>3HZ1G5L;$-A8VAE
M>R1F:6QE;F%M97T@/2`D9G5L;&YA;64["B`@("`@("`@?0H@("`@("`@(&5L
M<VEF("@@)&9U;&QN86UE(#U^(&U\7B\_<VAL:6(O?"!A;F0@9&5F:6YE9"`D
M14Y6>U!!4E]414U0?2`I('L*("`@("`@("`@("`@(R!S:&]U;&0@8F4@;6]V
M960@=&\@7W1E;7!F:6QE*"D*("`@("`@("`@("`@;7D@)&9I;&5N86UE(#T@
M(B1%3E9[4$%27U1%35!]+R1B87-E;F%M921E>'0B.PH@("`@("`@("`@("!O
M=71S*")32$Q)0CH@)&9I;&5N86UE7&XB*3L*("`@("`@("`@("`@;W!E;B!M
M>2`D;W5T+"`G/B<L("1F:6QE;F%M92!O<B!D:64@)"$["B`@("`@("`@("`@
M(&)I;FUO9&4H)&]U="D["B`@("`@("`@("`@('!R:6YT("1O=70@)&)U9CL*
M("`@("`@("`@("`@8VQO<V4@)&]U=#L*("`@("`@("!]"B`@("`@("`@96QS
M92!["B`@("`@("`@("`@("1R97%U:7)E7VQI<W1[)&9U;&QN86UE?2`]"B`@
M("`@("`@("`@("1005(Z.DAE879Y.CI-;V1U;&5#86-H97LD9G5L;&YA;65]
M(#T@>PH@("`@("`@("`@("`@("`@8G5F(#T^("1B=68L"B`@("`@("`@("`@
M("`@("!C<F,@/3X@)&-R8RP*("`@("`@("`@("`@("`@(&YA;64@/3X@)&9U
M;&QN86UE+`H@("`@("`@("`@("!].PH@("`@("`@('T*("`@("`@("!R96%D
M(%]&2"P@)&)U9BP@-#L*("`@('T*("`@(",@?7U]"@H@("`@;&]C86P@0$E.
M0R`]("AS=6(@>PH@("`@("`@(&UY("@D<V5L9BP@)&UO9'5L92D@/2!`7SL*
M"B`@("`@("`@<F5T=7)N(&EF(')E9B`D;6]D=6QE(&]R("$D;6]D=6QE.PH*
M("`@("`@("!M>2`D9FEL96YA;64@/2!D96QE=&4@)')E<75I<F5?;&ES='LD
M;6]D=6QE?2!\?"!D;R!["B`@("`@("`@("`@(&UY("1K97D["B`@("`@("`@
M("`@(&9O<F5A8V@@*&ME>7,@)7)E<75I<F5?;&ES="D@>PH@("`@("`@("`@
M("`@("`@;F5X="!U;FQE<W,@+UQ1)&UO9'5L95Q%)"\["B`@("`@("`@("`@
M("`@("`D:V5Y(#T@)%\[(&QA<W0["B`@("`@("`@("`@('T*("`@("`@("`@
M("`@9&5L971E("1R97%U:7)E7VQI<W1[)&ME>7T@:68@9&5F:6YE9"@D:V5Y
M*3L*("`@("`@("!](&]R(')E='5R;CL*"B`@("`@("`@)$E.0WLD;6]D=6QE
M?2`]("(O;&]A9&5R+R1F:6QE;F%M92\D;6]D=6QE(CL*"B`@("`@("`@:68@
M*"1%3E9[4$%27T-,14%.?2!A;F0@9&5F:6YE9"@F24\Z.D9I;&4Z.FYE=RDI
M('L*("`@("`@("`@("`@;7D@)&9H(#T@24\Z.D9I;&4M/FYE=U]T;7!F:6QE
M(&]R(&1I92`D(3L*("`@("`@("`@("`@8FEN;6]D92@D9F@I.PH@("`@("`@
M("`@("!P<FEN="`D9F@@)&9I;&5N86UE+3Y[8G5F?3L*("`@("`@("`@("`@
M<V5E:R@D9F@L(#`L(#`I.PH@("`@("`@("`@("!R971U<FX@)&9H.PH@("`@
M("`@('T*("`@("`@("!E;'-E('L*("`@("`@("`@("`@;7D@*"1O=70L("1N
M86UE*2`](%]T96UP9FEL92@G+G!M)RP@)&9I;&5N86UE+3Y[8W)C?2D["B`@
M("`@("`@("`@(&EF("@D;W5T*2!["B`@("`@("`@("`@("`@("!B:6YM;V1E
M*"1O=70I.PH@("`@("`@("`@("`@("`@<')I;G0@)&]U="`D9FEL96YA;64M
M/GMB=69].PH@("`@("`@("`@("`@("`@8VQO<V4@)&]U=#L*("`@("`@("`@
M("`@?0H@("`@("`@("`@("!O<&5N(&UY("1F:"P@)SPG+"`D;F%M92!O<B!D
M:64@)"$["B`@("`@("`@("`@(&)I;FUO9&4H)&9H*3L*("`@("`@("`@("`@
M<F5T=7)N("1F:#L*("`@("`@("!]"@H@("`@("`@(&1I92`B0F]O='-T<F%P
M<&EN9R!F86EL960Z(&-A;FYO="!F:6YD("1M;V1U;&4A7&XB.PH@("`@?2P@
M0$E.0RD["@H@("`@(R!.;W<@;&]A9"!A;&P@8G5N9&QE9"!F:6QE<R![>WL*
M"B`@("`C(&EN:71I86QI>F4@<VAA<F5D(&]B:F5C="!P<F]C97-S:6YG"B`@
M("!R97%U:7)E(%A33&]A9&5R.PH@("`@<F5Q=6ER92!005(Z.DAE879Y.PH@
M("`@<F5Q=6ER92!#87)P.CI(96%V>3L*("`@(')E<75I<F4@17AP;W)T97(Z
M.DAE879Y.PH@("`@4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PH*
M("`@(",@;F]W(&QE="=S('1R>2!G971T:6YG(&AE;'!E<B!M;V1U;&5S(&9R
M;VT@=VET:&EN"B`@("!R97%U:7)E($E/.CI&:6QE.PH*("`@(",@;&]A9"!R
M97-T(&]F('1H92!G<F]U<"!I;@H@("`@=VAI;&4@*&UY("1F:6QE;F%M92`]
M("AS;W)T(&ME>7,@)7)E<75I<F5?;&ES="E;,%TI('L*("`@("`@("`C;&]C
M86P@)$E.0WLG0W=D+G!M)WT@/2!?7T9)3$5?7R!I9B`D7D\@;F4@)TU35VEN
M,S(G.PH@("`@("`@('5N;&5S<R`H)$E.0WLD9FEL96YA;65](&]R("1F:6QE
M;F%M92`]?B`O0E-$4$%.+RD@>PH@("`@("`@("`@("`C(')E<75I<F4@;6]D
M=6QE<RP@9&\@;W1H97(@97AE8W5T86)L92!F:6QE<PH@("`@("`@("`@("!I
M9B`H)&9I;&5N86UE(#U^("]<+G!M8S\D+VDI('L*("`@("`@("`@("`@("`@
M(')E<75I<F4@)&9I;&5N86UE.PH@("`@("`@("`@("!]"B`@("`@("`@("`@
M(&5L<V4@>PH@("`@("`@("`@("`@("`@(R!3:VEP($%C=&EV95-T871E)W,@
M<VET96-U<W1O;6EZ92YP;"!F:6QE.@H@("`@("`@("`@("`@("`@9&\@)&9I
M;&5N86UE('5N;&5S<R`D9FEL96YA;64@/7X@+W-I=&5C=7-T;VUI>F5<+G!L
M)"\["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("`@("`@9&5L971E("1R
M97%U:7)E7VQI<W1[)&9I;&5N86UE?3L*("`@('T*"B`@("`C('U]?0H*("`@
M(&QA<W0@=6YL97-S("1B=68@97$@(E!+7#`P,UPP,#0B.PH@("`@)'-T87)T
M7W!O<R`]("AT96QL(%]&2"D@+2`T.PI]"B,@?7U]"@HC($%R9W5M96YT('!R
M;V-E<W-I;F<@>WM["FUY($!P87)?87)G<SL*;7D@*"1O=70L("1B=6YD;&4L
M("1L;V=F:"P@)&-A8VAE7VYA;64I.PH*9&5L971E("1%3E9[4$%27T%04%]2
M155317T[(",@<V%N:71I>F4@*%)%55-%(&UA>2!B92!A('-E8W5R:71Y('!R
M;V)L96TI"@HD<75I970@/2`P('5N;&5S<R`D14Y6>U!!4E]$14)51WT["B,@
M1&]N)W0@<W=A;&QO=R!A<F=U;65N=',@9F]R(&-O;7!I;&5D(&5X96-U=&%B
M;&5S('=I=&AO=70@+2UP87(M;W!T:6]N<PII9B`H(21S=&%R=%]P;W,@;W(@
M*"1!4D=66S!=(&5Q("<M+7!A<BUO<'1I;VYS)R`F)B!S:&EF="DI('L*("`@
M(&UY("5D:7-T7V-M9"`]('%W*`H@("`@("`@('`@("!B;&EB7W1O7W!A<@H@
M("`@("`@(&D@("!I;G-T86QL7W!A<@H@("`@("`@('4@("!U;FEN<W1A;&Q?
M<&%R"B`@("`@("`@<R`@('-I9VY?<&%R"B`@("`@("`@=B`@('9E<FEF>5]P
M87(*("`@("D["@H@("`@(R!I9B!T:&4@87!P(&ES(&EN=F]K960@87,@(F%P
M<&YA;64@+2UP87(M;W!T:6]N<R`M+7)E=7-E(%!23T=204T@0%!23T=?05)'
M5B(L"B`@("`C('5S92!T:&4@87!P('1O(')U;B!T:&4@9VEV96X@<&5R;"!C
M;V1E(&EN<W1E860@;V8@86YY=&AI;F<@9G)O;2!T:&4*("`@(",@87!P(&ET
M<V5L9B`H8G5T('-T:6QL('-E="!U<"!T:&4@;F]R;6%L(&%P<"!E;G9I<F]N
M;65N="!A;F0@0$E.0RD*("`@(&EF("A`05)'5B!A;F0@)$%21U9;,%T@97$@
M)RTM<F5U<V4G*2!["B`@("`@("`@<VAI9G0@0$%21U8["B`@("`@("`@)$5.
M5GM005)?05!07U)%55-%?2`]('-H:69T($!!4D=6.PH@("`@?0H@("`@96QS
M92![(",@;F]R;6%L('!A<FP@8F5H879I;W5R"@H@("`@("`@(&UY($!A9&1?
M=&]?:6YC.PH@("`@("`@('=H:6QE("A`05)'5BD@>PH@("`@("`@("`@("`D
M05)'5ELP72`]?B`O7BTH6T%)34]"3&)Q<&EU<U1V72DH+BHI+R!O<B!L87-T
M.PH*("`@("`@("`@("`@:68@*"0Q(&5Q("=))RD@>PH@("`@("`@("`@("`@
M("`@<'5S:"!`861D7W1O7VEN8RP@)#(["B`@("`@("`@("`@('T*("`@("`@
M("`@("`@96QS:68@*"0Q(&5Q("=-)RD@>PH@("`@("`@("`@("`@("`@979A
M;"`B=7-E("0R(CL*("`@("`@("`@("`@?0H@("`@("`@("`@("!E;'-I9B`H
M)#$@97$@)T$G*2!["B`@("`@("`@("`@("`@("!U;G-H:69T($!P87)?87)G
M<RP@)#(["B`@("`@("`@("`@('T*("`@("`@("`@("`@96QS:68@*"0Q(&5Q
M("=/)RD@>PH@("`@("`@("`@("`@("`@)&]U="`]("0R.PH@("`@("`@("`@
M("!]"B`@("`@("`@("`@(&5L<VEF("@D,2!E<2`G8B<I('L*("`@("`@("`@
M("`@("`@("1B=6YD;&4@/2`G<VET92<["B`@("`@("`@("`@('T*("`@("`@
M("`@("`@96QS:68@*"0Q(&5Q("=")RD@>PH@("`@("`@("`@("`@("`@)&)U
M;F1L92`]("=A;&PG.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&5L<VEF
M("@D,2!E<2`G<2<I('L*("`@("`@("`@("`@("`@("1Q=6EE="`](#$["B`@
M("`@("`@("`@('T*("`@("`@("`@("`@96QS:68@*"0Q(&5Q("=,)RD@>PH@
M("`@("`@("`@("`@("`@;W!E;B`D;&]G9F@L("(^/B(L("0R(&]R(&1I92`B
M6%A8.B!#86YN;W0@;W!E;B!L;V<Z("0A(CL*("`@("`@("`@("`@?0H@("`@
M("`@("`@("!E;'-I9B`H)#$@97$@)U0G*2!["B`@("`@("`@("`@("`@("`D
M8V%C:&5?;F%M92`]("0R.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("!S
M:&EF="A`05)'5BD["@H@("`@("`@("`@("!I9B`H;7D@)&-M9"`]("1D:7-T
M7V-M9'LD,7TI('L*("`@("`@("`@("`@("`@(&1E;&5T92`D14Y6>R=005)?
M5$5-4"=].PH@("`@("`@("`@("`@("`@:6YI=%]I;F,H*3L*("`@("`@("`@
M("`@("`@(')E<75I<F4@4$%2.CI$:7-T.PH@("`@("`@("`@("`@("`@)GLB
M4$%2.CI$:7-T.CHD8VUD(GTH*2!U;FQE<W,@0$%21U8["B`@("`@("`@("`@
M("`@("`F>R)005(Z.D1I<W0Z.B1C;60B?2@D7RD@9F]R($!!4D=6.PH@("`@
M("`@("`@("`@("`@97AI=#L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@
M("`@("`@=6YS:&EF="!`24Y#+"!`861D7W1O7VEN8SL*("`@('T*?0H*(R!8
M6%@@+2T@861D("TM<&%R+61E8G5G('-U<'!O<G0A"@HC('U]?0H*(R!/=71P
M=70@;6]D92`H+4\I(&AA;F1L:6YG('M[>PII9B`H)&]U="D@>PH@("`@>PH@
M("`@("`@("-L;V-A;"`D24Y#>R=#=V0N<&TG?2`](%]?1DE,15]?(&EF("1>
M3R!N92`G35-7:6XS,B<["B`@("`@("`@<F5Q=6ER92!)3SHZ1FEL93L*("`@
M("`@("!R97%U:7)E($%R8VAI=F4Z.EII<#L*("`@('T*"B`@("!M>2`D<&%R
M(#T@<VAI9G0H0$%21U8I.PH@("`@;7D@)'II<#L*"@H@("`@:68@*&1E9FEN
M960@)'!A<BD@>PH@("`@("`@(&]P96X@;7D@)&9H+"`G/"<L("1P87(@;W(@
M9&EE(")#86YN;W0@9FEN9"`G)'!A<B<Z("0A(CL*("`@("`@("!B:6YM;V1E
M*"1F:"D["B`@("`@("`@8FQE<W,H)&9H+"`G24\Z.D9I;&4G*3L*"B`@("`@
M("`@)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W.PH@("`@("`@("@@)'II<"T^
M<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!A<BD@/3T@07)C:&EV93HZ6FEP
M.CI!6E]/2R@I("D*("`@("`@("`@("`@;W(@9&EE(")296%D("<D<&%R)R!E
M<G)O<CH@)"$B.PH@("`@?0H*"B`@("!M>2`E96YV(#T@9&\@>PH@("`@("`@
M(&EF("@D>FEP(&%N9"!M>2`D;65T82`]("1Z:7`M/F-O;G1E;G1S*"=-151!
M+GEM;"<I*2!["B`@("`@("`@("`@("1M971A(#U^(',O+BI><&%R.B0O+VUS
M.PH@("`@("`@("`@("`D;65T82`]?B!S+UY<4RXJ+R]M<SL*("`@("`@("`@
M("`@)&UE=&$@/7X@+UX@("A;7CI=*RDZ("@N*RDD+VUG.PH@("`@("`@('T*
M("`@('T["@H@("`@(R!/<&5N(&EN<'5T(&%N9"!O=71P=70@9FEL97,@>WM[
M"B`@("!L;V-A;"`D+R`](%PT.PH*("`@(&EF("AD969I;F5D("1P87(I('L*
M("`@("`@("!O<&5N(%!!4BP@)SPG+"`D<&%R(&]R(&1I92`B)"$Z("1P87(B
M.PH@("`@("`@(&)I;FUO9&4H4$%2*3L*("`@("`@("!D:64@(B1P87(@:7,@
M;F]T(&$@4$%2(&9I;&4B('5N;&5S<R`\4$%2/B!E<2`B4$M<,#`S7#`P-"([
M"B`@("!]"@H@("`@0W)E871E4&%T:"@D;W5T*2`["B`@("`*("`@(&UY("1F
M:"`]($E/.CI&:6QE+3YN97<H"B`@("`@("`@)&]U="P*("`@("`@("!)3SHZ
M1FEL93HZ3U]#4D5!5"@I('P@24\Z.D9I;&4Z.D]?5U)/3DQ9*"D@?"!)3SHZ
M1FEL93HZ3U]44E5.0R@I+`H@("`@("`@(#`W-S<L"B`@("`I(&]R(&1I92`D
M(3L*("`@(&)I;FUO9&4H)&9H*3L*"B`@("`D+R`]("AD969I;F5D("1D871A
M7W!O<RD@/R!<)&1A=&%?<&]S(#H@=6YD968["B`@("!S965K(%]&2"P@,"P@
M,#L*("`@(&UY("1L;V%D97(@/2!S8V%L87(@/%]&2#X["B`@("!I9B`H(21%
M3E9[4$%27U9%4D)!5$E-?2!A;F0@)&QO861E<B`]?B`O7B@_.B,A?%Q`<F5M
M*2\I('L*("`@("`@("!R97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I<#L*
M("`@("`@("!005(Z.D9I;'1E<CHZ4&]D4W1R:7`M/FYE=RT^87!P;'DH7"1L
M;V%D97(L("0P*0H@("`@?0H@("`@9F]R96%C:"!M>2`D:V5Y("AS;W)T(&ME
M>7,@)65N=BD@>PH@("`@("`@(&UY("1V86P@/2`D96YV>R1K97E](&]R(&YE
M>'0["B`@("`@("`@)'9A;"`](&5V86P@)'9A;"!I9B`D=F%L(#U^("]>6R<B
M72\["B`@("`@("`@;7D@)&UA9VEC(#T@(E]?14Y67U!!4E\B("X@=6,H)&ME
M>2D@+B`B7U\B.PH@("`@("`@(&UY("1S970@/2`B4$%27R(@+B!U8R@D:V5Y
M*2`N("(])'9A;"(["B`@("`@("`@)&QO861E<B`]?B!S>R1M86=I8R@@*RE]
M>PH@("`@("`@("`@("`D;6%G:6,@+B`D<V5T("X@*"<@)R!X("AL96YG=&@H
M)#$I("T@;&5N9W1H*"1S970I*2D*("`@("`@("!]96<["B`@("!]"B`@("`D
M9F@M/G!R:6YT*"1L;V%D97(I.PH@("`@)"\@/2!U;F1E9CL*("`@(",@?7U]
M"@H@("`@(R!7<FET92!B=6YD;&5D(&UO9'5L97,@>WM["B`@("!I9B`H)&)U
M;F1L92D@>PH@("`@("`@(')E<75I<F4@4$%2.CI(96%V>3L*("`@("`@("!0
M05(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["B`@("`@("`@:6YI=%]I
M;F,H*3L*"B`@("`@("`@<F5Q=6ER95]M;V1U;&5S*"D["@H@("`@("`@(&UY
M($!I;F,@/2!S;W)T('L*("`@("`@("`@("`@;&5N9W1H*"1B*2`\/3X@;&5N
M9W1H*"1A*0H@("`@("`@('T@9W)E<"!["B`@("`@("`@("`@("$O0E-$4$%.
M+PH@("`@("`@('T@9W)E<"!["B`@("`@("`@("`@("@D8G5N9&QE(&YE("=S
M:71E)RD@;W(*("`@("`@("`@("`@*"1?(&YE("1#;VYF:6<Z.D-O;F9I9WMA
M<F-H;&EB97AP?2!A;F0*("`@("`@("`@("`@("1?(&YE("1#;VYF:6<Z.D-O
M;F9I9WMP<FEV;&EB97AP?2D["B`@("`@("`@?2!`24Y#.PH*("`@("`@("`C
M($9I;&4@97AI<W1S('1E<W0@861D960@=&\@9FEX(%)4(",T,3<Y,#H*("`@
M("`@("`C($9U;FYY+"!N;VXM97AI<W1I;F<@96YT<GD@:6X@7SPN+BXN875T
M;R]#;VUP<F5S<R]287<O6FQI8B]A=71O<W!L:70N:7@N"B`@("`@("`@(R!4
M:&ES(&ES(&$@8F%N9"UA:60@9FEX('=I=&@@;F\@9&5E<&5R(&=R87-P(&]F
M('1H92!I<W-U92X*("`@("`@("`C(%-O;65B;V1Y('!L96%S92!G;R!T:')O
M=6=H('1H92!P86EN(&]F('5N9&5R<W1A;F1I;F<@=VAA="=S(&AA<'!E;FEN
M9RP*("`@("`@("`C($D@9F%I;&5D+B`M+2!3=&5F9F5N"B`@("`@("`@;7D@
M)69I;&5S.PH@("`@("`@("]>7SPH+BLI)"\@86YD("UE("0Q(&%N9"`D9FEL
M97-[)#%]*RL@9F]R(&ME>7,@)3HZ.PH@("`@("`@("1F:6QE<WLD7WTK*R!F
M;W(@=F%L=65S("5)3D,["@H@("`@("`@(&UY("1L:6)?97AT(#T@)$-O;F9I
M9SHZ0V]N9FEG>VQI8E]E>'1].PH@("`@("`@(&UY("5W<FET=&5N.PH*("`@
M("`@("!F;W)E86-H("AS;W)T(&ME>7,@)69I;&5S*2!["B`@("`@("`@("`@
M(&UY("@D;F%M92P@)&9I;&4I.PH*("`@("`@("`@("`@9F]R96%C:"!M>2`D
M9&ER("A`:6YC*2!["B`@("`@("`@("`@("`@("!I9B`H)&YA;64@/2`D4$%2
M.CI(96%V>3HZ1G5L;$-A8VAE>R1??2D@>PH@("`@("`@("`@("`@("`@("`@
M("1F:6QE(#T@)%\["B`@("`@("`@("`@("`@("`@("`@;&%S=#L*("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@("`@(&5L<VEF("@O7BA<421D:7)<
M15PO*"XJ6UY#8UTI*5Q:+VDI('L*("`@("`@("`@("`@("`@("`@("`H)&9I
M;&4L("1N86UE*2`]("@D,2P@)#(I.PH@("`@("`@("`@("`@("`@("`@(&QA
M<W0["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!E;'-I9B`H
M;2%>+VQO861E<B];7B]=*R\H+BI;7D-C72E<6B$I('L*("`@("`@("`@("`@
M("`@("`@("!I9B`H;7D@)')E9B`]("1005(Z.DAE879Y.CI-;V1U;&5#86-H
M97LD,7TI('L*("`@("`@("`@("`@("`@("`@("`@("`@*"1F:6QE+"`D;F%M
M92D@/2`H)')E9BP@)#$I.PH@("`@("`@("`@("`@("`@("`@("`@("!L87-T
M.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("!E
M;'-I9B`H+68@(B1D:7(O)#$B*2!["B`@("`@("`@("`@("`@("`@("`@("`@
M("@D9FEL92P@)&YA;64I(#T@*"(D9&ER+R0Q(BP@)#$I.PH@("`@("`@("`@
M("`@("`@("`@("`@("!L87-T.PH@("`@("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H*("`@("`@("`@("`@;F5X
M="!U;FQE<W,@9&5F:6YE9"`D;F%M92!A;F0@;F]T("1W<FET=&5N>R1N86UE
M?2LK.PH@("`@("`@("`@("!N97AT(&EF("%R968H)&9I;&4I(&%N9"`D9FEL
M92`]?B`O7"Y<421L:6)?97AT7$4D+SL*("`@("`@("`@("`@;W5T<R@@:F]I
M;B`B(BP*("`@("`@("`@("`@("`@('%Q*%!A8VMI;F<@(BDL(')E9B`D9FEL
M92`_("1F:6QE+3Y[;F%M97T@.B`D9FEL92P*("`@("`@("`@("`@("`@('%Q
M*"(N+BXI"B`@("`@("`@("`@("D["@H@("`@("`@("`@("!M>2`D8V]N=&5N
M=#L*("`@("`@("`@("`@:68@*')E9B@D9FEL92DI('L*("`@("`@("`@("`@
M("`@("1C;VYT96YT(#T@)&9I;&4M/GMB=69].PH@("`@("`@("`@("!]"B`@
M("`@("`@("`@(&5L<V4@>PH@("`@("`@("`@("`@("`@;W!E;B!&24Q%+"`G
M/"<L("1F:6QE(&]R(&1I92`B0V%N)W0@;W!E;B`D9FEL93H@)"$B.PH@("`@
M("`@("`@("`@("`@8FEN;6]D92A&24Q%*3L*("`@("`@("`@("`@("`@("1C
M;VYT96YT(#T@/$9)3$4^.PH@("`@("`@("`@("`@("`@8VQO<V4@1DE,13L*
M"B`@("`@("`@("`@("`@("!005(Z.D9I;'1E<CHZ4&]D4W1R:7`M/FYE=RT^
M87!P;'DH7"1C;VYT96YT+"`D9FEL92D*("`@("`@("`@("`@("`@("`@("!I
M9B`A)$5.5GM005)?5D520D%424U](&%N9"`D;F%M92`]?B`O7"XH/SIP;7QI
M>'QA;"DD+VD["@H@("`@("`@("`@("`@("`@(R!$;R!N;W0@;&5T(%A33&]A
M9&5R('!I8VL@=7`@875T;R\J(&9R;VT@96YV:7)O;FUE;G0*("`@("`@("`@
M("`@("`@("1C;VYT96YT(#U^(',O9V]T;R`K<F5T<GD@*W5N;&5S<R`K+BHO
M9V]T;R!R971R>3LO"B`@("`@("`@("`@("`@("`@("`@:68@;&,H)&YA;64I
M(&5Q(&QC*")84TQO861E<BYP;2(I.PH@("`@("`@("`@("!]"@H@("`@("`@
M("`@("!O=71S*'%Q*%=R:71T96X@87,@(B1N86UE(BDI.PH@("`@("`@("`@
M("`D9F@M/G!R:6YT*")&24Q%(BD["B`@("`@("`@("`@("1F:"T^<')I;G0H
M<&%C:R@G3B<L(&QE;F=T:"@D;F%M92D@*R`Y*2D["B`@("`@("`@("`@("1F
M:"T^<')I;G0H<W!R:6YT9B@*("`@("`@("`@("`@("`@("(E,#AX+R5S(BP@
M07)C:&EV93HZ6FEP.CIC;VUP=71E0U)#,S(H)&-O;G1E;G0I+"`D;F%M90H@
M("`@("`@("`@("`I*3L*("`@("`@("`@("`@)&9H+3YP<FEN="AP86-K*"=.
M)RP@;&5N9W1H*"1C;VYT96YT*2DI.PH@("`@("`@("`@("`D9F@M/G!R:6YT
M*"1C;VYT96YT*3L*("`@("`@("!]"B`@("!]"B`@("`C('U]?0H*("`@(",@
M3F]W('=R:71E(&]U="!T:&4@4$%2(&%N9"!M86=I8R!S=')I;F=S('M[>PH@
M("`@)'II<"T^=W)I=&54;T9I;&5(86YD;&4H)&9H*2!I9B`D>FEP.PH*("`@
M("1C86-H95]N86UE(#T@<W5B<W1R("1C86-H95]N86UE+"`P+"`T,#L*("`@
M(&EF("@A)&-A8VAE7VYA;64@86YD(&UY("1M=&EM92`]("AS=&%T*"1O=70I
M*5LY72D@>PH@("`@("`@(&UY("1C='@@/2!E=F%L('L@<F5Q=6ER92!$:6=E
M<W0Z.E-(03L@1&EG97-T.CI32$$M/FYE=R@Q*2!]"B`@("`@("`@("`@('Q\
M(&5V86P@>R!R97%U:7)E($1I9V5S=#HZ4TA!,3L@1&EG97-T.CI32$$Q+3YN
M97<@?0H@("`@("`@("`@("!\?"!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.DU$
M-3L@1&EG97-T.CI-1#4M/FYE=R!].PH*("`@("`@("`C(%=O<FMA<F]U;F0@
M9F]R(&)U9R!I;B!$:6=E<W0Z.E-(02`U+C,X(&%N9"`U+C,Y"B`@("`@("`@
M;7D@)'-H85]V97)S:6]N(#T@979A;"![("1$:6=E<W0Z.E-(03HZ5D524TE/
M3B!]('Q\(#`["B`@("`@("`@:68@*"1S:&%?=F5R<VEO;B!E<2`G-2XS."<@
M;W(@)'-H85]V97)S:6]N(&5Q("<U+C,Y)RD@>PH@("`@("`@("`@("`D8W1X
M+3YA9&1F:6QE*"1O=70L(")B(BD@:68@*"1C='@I.PH@("`@("`@('T*("`@
M("`@("!E;'-E('L*("`@("`@("`@("`@:68@*"1C='@@86YD(&]P96XH;7D@
M)&9H+"`B/"1O=70B*2D@>PH@("`@("`@("`@("`@("`@8FEN;6]D92@D9F@I
M.PH@("`@("`@("`@("`@("`@)&-T>"T^861D9FEL92@D9F@I.PH@("`@("`@
M("`@("`@("`@8VQO<V4H)&9H*3L*("`@("`@("`@("`@?0H@("`@("`@('T*
M"B`@("`@("`@)&-A8VAE7VYA;64@/2`D8W1X(#\@)&-T>"T^:&5X9&EG97-T
M(#H@)&UT:6UE.PH@("`@?0H@("`@)&-A8VAE7VYA;64@+CT@(EPP(B!X("@T
M,2`M(&QE;F=T:"`D8V%C:&5?;F%M92D["B`@("`D8V%C:&5?;F%M92`N/2`B
M0T%#2$4B.PH@("`@)&9H+3YP<FEN="@D8V%C:&5?;F%M92D["B`@("`D9F@M
M/G!R:6YT*'!A8VLH)TXG+"`D9F@M/G1E;&P@+2!L96YG=&@H)&QO861E<BDI
M*3L*("`@("1F:"T^<')I;G0H(EQN4$%2+G!M7&XB*3L*("`@("1F:"T^8VQO
M<V4["B`@("!C:&UO9"`P-S4U+"`D;W5T.PH@("`@(R!]?7T*"B`@("!E>&ET
M.PI]"B,@?7U]"@HC(%!R97!A<F4@)'!R;V=N86UE(&EN=&\@4$%2(&9I;&4@
M8V%C:&4@>WM["GL*("`@(&QA<W0@=6YL97-S(&1E9FEN960@)'-T87)T7W!O
M<SL*"B`@("!?9FEX7W!R;V=N86UE*"D["@H@("`@(R!.;W<@;&]A9"!T:&4@
M4$%2(&9I;&4@86YD('!U="!I="!I;G1O(%!!4CHZ3&EB0V%C:&4@>WM["B`@
M("!R97%U:7)E(%!!4CL*("`@(%!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D
M97(H*3L*"@H@("`@>PH@("`@("`@("-L;V-A;"`D24Y#>R=#=V0N<&TG?2`]
M(%]?1DE,15]?(&EF("1>3R!N92`G35-7:6XS,B<["B`@("`@("`@<F5Q=6ER
M92!&:6QE.CI&:6YD.PH@("`@("`@(')E<75I<F4@07)C:&EV93HZ6FEP.PH@
M("`@?0H@("`@;7D@)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W.PH@("`@;7D@
M)&9H(#T@24\Z.D9I;&4M/FYE=SL*("`@("1F:"T^9F1O<&5N*&9I;&5N;RA?
M1D@I+"`G<B<I(&]R(&1I92`B)"$Z("1`(CL*("`@("1Z:7`M/G)E861&<F]M
M1FEL94AA;F1L92@D9F@L("1P<F]G;F%M92D@/3T@07)C:&EV93HZ6FEP.CI!
M6E]/2R@I(&]R(&1I92`B)"$Z("1`(CL*"B`@("!P=7-H($!005(Z.DQI8D-A
M8VAE+"`D>FEP.PH@("`@)%!!4CHZ3&EB0V%C:&5[)'!R;V=N86UE?2`]("1Z
M:7`["@H@("`@)'%U:65T(#T@(21%3E9[4$%27T1%0E5'?3L*("`@(&]U=',H
M<7$H7"1%3E9[4$%27U1%35!](#T@(B1%3E9[4$%27U1%35!](BDI.PH*("`@
M(&EF("AD969I;F5D("1%3E9[4$%27U1%35!]*2![(",@<VAO=6QD(&)E('-E
M="!A="!T:&ES('!O:6YT(0H@("`@("`@(&9O<F5A8V@@;7D@)&UE;6)E<B`H
M("1Z:7`M/FUE;6)E<G,@*2!["B`@("`@("`@("`@(&YE>'0@:68@)&UE;6)E
M<BT^:7-$:7)E8W1O<GD["B`@("`@("`@("`@(&UY("1M96UB97)?;F%M92`]
M("1M96UB97(M/F9I;&5.86UE.PH@("`@("`@("`@("!N97AT('5N;&5S<R`D
M;65M8F5R7VYA;64@/7X@;7L*("`@("`@("`@("`@("`@(%X*("`@("`@("`@
M("`@("`@("\_<VAL:6(O"B`@("`@("`@("`@("`@("`H/SHD0V]N9FEG.CI#
M;VYF:6=[=F5R<VEO;GTO*3\*("`@("`@("`@("`@("`@("@_.B1#;VYF:6<Z
M.D-O;F9I9WMA<F-H;F%M97TO*3\*("`@("`@("`@("`@("`@("A;7B]=*RD*
M("`@("`@("`@("`@("`@("0*("`@("`@("`@("`@?7@["B`@("`@("`@("`@
M(&UY("1E>'1R86-T7VYA;64@/2`D,3L*("`@("`@("`@("`@;7D@)&1E<W1?
M;F%M92`]($9I;&4Z.E-P96,M/F-A=&9I;&4H)$5.5GM005)?5$5-4'TL("1E
M>'1R86-T7VYA;64I.PH@("`@("`@("`@("!I9B`H+68@)&1E<W1?;F%M92`F
M)B`M<R!?(#T]("1M96UB97(M/G5N8V]M<')E<W-E9%-I>F4H*2D@>PH@("`@
M("`@("`@("`@("`@;W5T<RAQ<2A3:VEP<&EN9R`B)&UE;6)E<E]N86UE(B!S
M:6YC92!I="!A;')E861Y(&5X:7-T<R!A="`B)&1E<W1?;F%M92(I*3L*("`@
M("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@(&]U=',H<7$H17AT
M<F%C=&EN9R`B)&UE;6)E<E]N86UE(B!T;R`B)&1E<W1?;F%M92(I*3L*("`@
M("`@("`@("`@("`@("1M96UB97(M/F5X=')A8W14;T9I;&5.86UE9"@D9&5S
M=%]N86UE*3L*("`@("`@("`@("`@("`@(&-H;6]D*#`U-34L("1D97-T7VYA
M;64I(&EF("1>3R!E<2`B:'!U>"(["B`@("`@("`@("`@('T*("`@("`@("!]
M"B`@("!]"B`@("`C('U]?0I]"B,@?7U]"@HC($EF('1H97)E)W,@;F\@;6%I
M;BYP;"!T;R!R=6XL('-H;W<@=7-A9V4@>WM["G5N;&5S<R`H)%!!4CHZ3&EB
M0V%C:&5[)'!R;V=N86UE?2D@>PH@("`@9&EE(#P\("(N(B!U;FQE<W,@0$%2
M1U8["E5S86=E.B`D,"!;("U!;&EB+G!A<B!=(%L@+4ED:7(@72!;("U-;6]D
M=6QE(%T@6R!S<F,N<&%R(%T@6R!P<F]G<F%M+G!L(%T*("`@("`@("0P(%L@
M+4)\+6(@72!;+4]O=71F:6QE72!S<F,N<&%R"BX*("`@("1%3E9[4$%27U!2
M3T=.04U%?2`]("1P<F]G;F%M92`]("0P(#T@<VAI9G0H0$%21U8I.PI]"B,@
M?7U]"@IS=6(@0W)E871E4&%T:"!["B`@("!M>2`H)&YA;64I(#T@0%\["B`@
M("`*("`@(')E<75I<F4@1FEL93HZ0F%S96YA;64["B`@("!M>2`H)&)A<V5N
M86UE+"`D<&%T:"P@)&5X="D@/2!&:6QE.CI"87-E;F%M93HZ9FEL97!A<G-E
M*"1N86UE+"`H)UPN+BHG*2D["B`@("`*("`@(')E<75I<F4@1FEL93HZ4&%T
M:#L*("`@(`H@("`@1FEL93HZ4&%T:#HZ;6MP871H*"1P871H*2!U;FQE<W,H
M+64@)'!A=&@I.R`C(&UK<&%T:"!D:65S('=I=&@@97)R;W(*?0H*<W5B(')E
M<75I<F5?;6]D=6QE<R!["B`@("`C;&]C86P@)$E.0WLG0W=D+G!M)WT@/2!?
M7T9)3$5?7R!I9B`D7D\@;F4@)TU35VEN,S(G.PH*("`@(')E<75I<F4@;&EB
M.PH@("`@<F5Q=6ER92!$>6YA3&]A9&5R.PH@("`@<F5Q=6ER92!I;G1E9V5R
M.PH@("`@<F5Q=6ER92!S=')I8W0["B`@("!R97%U:7)E('=A<FYI;F=S.PH@
M("`@<F5Q=6ER92!V87)S.PH@("`@<F5Q=6ER92!#87)P.PH@("`@<F5Q=6ER
M92!#87)P.CI(96%V>3L*("`@(')E<75I<F4@17)R;F\["B`@("!R97%U:7)E
M($5X<&]R=&5R.CI(96%V>3L*("`@(')E<75I<F4@17AP;W)T97(["B`@("!R
M97%U:7)E($9C;G1L.PH@("`@<F5Q=6ER92!&:6QE.CI496UP.PH@("`@<F5Q
M=6ER92!&:6QE.CI3<&5C.PH@("`@<F5Q=6ER92!84TQO861E<CL*("`@(')E
M<75I<F4@0V]N9FEG.PH@("`@<F5Q=6ER92!)3SHZ2&%N9&QE.PH@("`@<F5Q
M=6ER92!)3SHZ1FEL93L*("`@(')E<75I<F4@0V]M<')E<W,Z.EIL:6(["B`@
M("!R97%U:7)E($%R8VAI=F4Z.EII<#L*("`@(')E<75I<F4@4$%2.PH@("`@
M<F5Q=6ER92!005(Z.DAE879Y.PH@("`@<F5Q=6ER92!005(Z.D1I<W0["B`@
M("!R97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I<#L*("`@(')E<75I<F4@
M871T<FEB=71E<SL*("`@(&5V86P@>R!R97%U:7)E($-W9"!].PH@("`@979A
M;"![(')E<75I<F4@5VEN,S(@?3L*("`@(&5V86P@>R!R97%U:7)E(%-C86QA
M<CHZ571I;"!].PH@("`@979A;"![(')E<75I<F4@07)C:&EV93HZ56YZ:7`Z
M.D)U<G-T('T["B`@("!E=F%L('L@<F5Q=6ER92!4:64Z.DAA<V@Z.DYA;65D
M0V%P='5R92!].PH@("`@979A;"![(')E<75I<F4@4&5R;$E/.R!R97%U:7)E
M(%!E<FQ)3SHZ<V-A;&%R('T["GT*"B,@5&AE($,@=F5R<VEO;B!O9B!T:&ES
M(&-O9&4@87!P96%R<R!I;B!M>6QD<B]M:W1M<&1I<BYC"B,@5&AI<R!C;V1E
M(&%L<V\@;&EV97,@:6X@4$%2.CI3971U<%1E;7`@87,@<V5T7W!A<E]T96UP
M7V5N=B$*<W5B(%]S971?<&%R7W1E;7`@>PH@("`@:68@*&1E9FEN960@)$5.
M5GM005)?5$5-4'T@86YD("1%3E9[4$%27U1%35!](#U^("\H+BLI+RD@>PH@
M("`@("`@("1P87)?=&5M<"`]("0Q.PH@("`@("`@(')E='5R;CL*("`@('T*
M"B`@("!F;W)E86-H(&UY("1P871H("@*("`@("`@("`H;6%P("1%3E9[)%]]
M+"!Q=R@@4$%27U1-4$1)4B!435!$25(@5$5-4$1)4B!414U0(%1-4"`I*2P*
M("`@("`@("!Q=R@@0SI<7%1%35`@+W1M<"`N("D*("`@("D@>PH@("`@("`@
M(&YE>'0@=6YL97-S(&1E9FEN960@)'!A=&@@86YD("UD("1P871H(&%N9"`M
M=R`D<&%T:#L*("`@("`@("!M>2`D=7-E<FYA;64["B`@("`@("`@;7D@)'!W
M=6ED.PH@("`@("`@(",@9&]E<R!N;W0@=V]R:R!E=F5R>7=H97)E.@H@("`@
M("`@(&5V86P@>R@D<'=U:60I(#T@9V5T<'=U:60H)#XI(&EF(&1E9FEN960@
M)#X[?3L*"B`@("`@("`@:68@*"!D969I;F5D*"97:6XS,CHZ3&]G:6Y.86UE
M*2`I('L*("`@("`@("`@("`@)'5S97)N86UE(#T@)E=I;C,R.CI,;V=I;DYA
M;64["B`@("`@("`@?0H@("`@("`@(&5L<VEF("AD969I;F5D("1P=W5I9"D@
M>PH@("`@("`@("`@("`D=7-E<FYA;64@/2`D<'=U:60["B`@("`@("`@?0H@
M("`@("`@(&5L<V4@>PH@("`@("`@("`@("`D=7-E<FYA;64@/2`D14Y6>U53
M15).04U%?2!\?"`D14Y6>U5315)]('Q\("=365-414TG.PH@("`@("`@('T*
M("`@("`@("`D=7-E<FYA;64@/7X@<R]<5R]?+V<["@H@("`@("`@(&UY("1S
M=&UP9&ER(#T@(B1P871H)$-O;F9I9WM?9&5L:6U]<&%R+21U<V5R;F%M92([
M"B`@("`@("`@;6MD:7(@)'-T;7!D:7(L(#`W-34["B`@("`@("`@:68@*"$D
M14Y6>U!!4E]#3$5!3GT@86YD(&UY("1M=&EM92`]("AS=&%T*"1P<F]G;F%M
M92DI6SE=*2!["B`@("`@("`@("`@(&]P96X@*&UY("1F:"P@(CPB+B`D<')O
M9VYA;64I.PH@("`@("`@("`@("!S965K("1F:"P@+3$X+"`R.PH@("`@("`@
M("`@("!S>7-R96%D("1F:"P@;7D@)&)U9BP@-CL*("`@("`@("`@("`@:68@
M*"1B=68@97$@(EPP0T%#2$4B*2!["B`@("`@("`@("`@("`@("!S965K("1F
M:"P@+34X+"`R.PH@("`@("`@("`@("`@("`@<WES<F5A9"`D9F@L("1B=68L
M(#0Q.PH@("`@("`@("`@("`@("`@)&)U9B`]?B!S+UPP+R]G.PH@("`@("`@
M("`@("`@("`@)'-T;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM?6-A8VAE+2(@
M+B`D8G5F.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&5L<V4@>PH@("`@
M("`@("`@("`@("`@;7D@)&-T>"`](&5V86P@>R!R97%U:7)E($1I9V5S=#HZ
M4TA!.R!$:6=E<W0Z.E-(02T^;F5W*#$I('T*("`@("`@("`@("`@("`@("`@
M("!\?"!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.E-(03$[($1I9V5S=#HZ4TA!
M,2T^;F5W('T*("`@("`@("`@("`@("`@("`@("!\?"!E=F%L('L@<F5Q=6ER
M92!$:6=E<W0Z.DU$-3L@1&EG97-T.CI-1#4M/FYE=R!].PH*("`@("`@("`@
M("`@("`@(",@5V]R:V%R;W5N9"!F;W(@8G5G(&EN($1I9V5S=#HZ4TA!(#4N
M,S@@86YD(#4N,SD*("`@("`@("`@("`@("`@(&UY("1S:&%?=F5R<VEO;B`]
M(&5V86P@>R`D1&EG97-T.CI32$$Z.E9%4E-)3TX@?2!\?"`P.PH@("`@("`@
M("`@("`@("`@:68@*"1S:&%?=F5R<VEO;B!E<2`G-2XS."<@;W(@)'-H85]V
M97)S:6]N(&5Q("<U+C,Y)RD@>PH@("`@("`@("`@("`@("`@("`@("1C='@M
M/F%D9&9I;&4H)'!R;V=N86UE+"`B8B(I(&EF("@D8W1X*3L*("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@("`@(&5L<V4@>PH@("`@("`@("`@("`@
M("`@("`@(&EF("@D8W1X(&%N9"!O<&5N*&UY("1F:"P@(CPD<')O9VYA;64B
M*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("!B:6YM;V1E*"1F:"D["B`@
M("`@("`@("`@("`@("`@("`@("`@("1C='@M/F%D9&9I;&4H)&9H*3L*("`@
M("`@("`@("`@("`@("`@("`@("`@8VQO<V4H)&9H*3L*("`@("`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@("`@("!]"@H@("`@("`@("`@("`@("`@
M)'-T;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM?6-A8VAE+2(@+B`H("1C='@@
M/R`D8W1X+3YH97AD:6=E<W0@.B`D;71I;64@*3L*("`@("`@("`@("`@?0H@
M("`@("`@("`@("!C;&]S92@D9F@I.PH@("`@("`@('T*("`@("`@("!E;'-E
M('L*("`@("`@("`@("`@)$5.5GM005)?0TQ%04Y](#T@,3L*("`@("`@("`@
M("`@)'-T;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM?71E;7`M)"0B.PH@("`@
M("`@('T*"B`@("`@("`@)$5.5GM005)?5$5-4'T@/2`D<W1M<&1I<CL*("`@
M("`@("!M:V1I<B`D<W1M<&1I<BP@,#<U-3L*("`@("`@("!L87-T.PH@("`@
M?0H*("`@("1P87)?=&5M<"`]("0Q(&EF("1%3E9[4$%27U1%35!](&%N9"`D
M14Y6>U!!4E]414U0?2`]?B`O*"XK*2\["GT*"G-U8B!?=&5M<&9I;&4@>PH@
M("`@;7D@*"1E>'0L("1C<F,I(#T@0%\["B`@("!M>2`H)&9H+"`D9FEL96YA
M;64I.PH*("`@("1F:6QE;F%M92`]("(D<&%R7W1E;7`O)&-R8R1E>'0B.PH*
M("`@(&EF("@D14Y6>U!!4E]#3$5!3GTI('L*("`@("`@("!U;FQI;FL@)&9I
M;&5N86UE(&EF("UE("1F:6QE;F%M93L*("`@("`@("!P=7-H($!T;7!F:6QE
M+"`D9FEL96YA;64["B`@("!]"B`@("!E;'-E('L*("`@("`@("!R971U<FX@
M*'5N9&5F+"`D9FEL96YA;64I(&EF("@M<B`D9FEL96YA;64I.PH@("`@?0H*
M("`@(&]P96X@)&9H+"`G/B<L("1F:6QE;F%M92!O<B!D:64@)"$["B`@("!B
M:6YM;V1E*"1F:"D["B`@("!R971U<FXH)&9H+"`D9FEL96YA;64I.PI]"@HC
M('-A;64@8V]D92!L:79E<R!I;B!005(Z.E-E='5P4')O9VYA;64Z.G-E=%]P
M<F]G;F%M90IS=6(@7W-E=%]P<F]G;F%M92!["B`@("!I9B`H9&5F:6YE9"`D
M14Y6>U!!4E]04D]'3D%-17T@86YD("1%3E9[4$%27U!23T=.04U%?2`]?B`O
M*"XK*2\I('L*("`@("`@("`D<')O9VYA;64@/2`D,3L*("`@('T*"B`@("`D
M<')O9VYA;64@?'P]("0P.PH*("`@(&EF("@D14Y6>U!!4E]414U0?2!A;F0@
M:6YD97@H)'!R;V=N86UE+"`D14Y6>U!!4E]414U0?2D@/CT@,"D@>PH@("`@
M("`@("1P<F]G;F%M92`]('-U8G-T<B@D<')O9VYA;64L(')I;F1E>"@D<')O
M9VYA;64L("1#;VYF:6=[7V1E;&EM?2D@*R`Q*3L*("`@('T*"B`@("!I9B`H
M(21%3E9[4$%27U!23T=.04U%?2!O<B!I;F1E>"@D<')O9VYA;64L("1#;VYF
M:6=[7V1E;&EM?2D@/CT@,"D@>PH@("`@("`@(&EF("AO<&5N(&UY("1F:"P@
M)SPG+"`D<')O9VYA;64I('L*("`@("`@("`@("`@<F5T=7)N(&EF("US("1F
M:#L*("`@("`@("!]"B`@("`@("`@:68@*"US("(D<')O9VYA;64D0V]N9FEG
M>U]E>&5](BD@>PH@("`@("`@("`@("`D<')O9VYA;64@+CT@)$-O;F9I9WM?
M97AE?3L*("`@("`@("`@("`@<F5T=7)N.PH@("`@("`@('T*("`@('T*"B`@
M("!F;W)E86-H(&UY("1D:7(@*'-P;&ET("]<421#;VYF:6=[<&%T:%]S97!]
M7$4O+"`D14Y6>U!!5$A]*2!["B`@("`@("`@;F5X="!I9B!E>&ES=',@)$5.
M5GM005)?5$5-4'T@86YD("1D:7(@97$@)$5.5GM005)?5$5-4'T["B`@("`@
M("`@)&1I<B`]?B!S+UQ1)$-O;F9I9WM?9&5L:6U]7$4D+R\["B`@("`@("`@
M*"@D<')O9VYA;64@/2`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M921#
M;VYF:6=[7V5X97TB*2P@;&%S="D*("`@("`@("`@("`@:68@+7,@(B1D:7(D
M0V]N9FEG>U]D96QI;7TD<')O9VYA;64D0V]N9FEG>U]E>&5](CL*("`@("`@
M("`H*"1P<F]G;F%M92`]("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE
M(BDL(&QA<W0I"B`@("`@("`@("`@(&EF("US("(D9&ER)$-O;F9I9WM?9&5L
M:6U])'!R;V=N86UE(CL*("`@('T*?0H*<W5B(%]F:7A?<')O9VYA;64@>PH@
M("`@)#`@/2`D<')O9VYA;64@?'P]("1%3E9[4$%27U!23T=.04U%?3L*("`@
M(&EF("AI;F1E>"@D<')O9VYA;64L("1#;VYF:6=[7V1E;&EM?2D@/"`P*2![
M"B`@("`@("`@)'!R;V=N86UE(#T@(BXD0V]N9FEG>U]D96QI;7TD<')O9VYA
M;64B.PH@("`@?0H*("`@(",@6%A8("T@:&%C:R!T;R!M86ME(%!71"!W;W)K
M"B`@("!M>2`D<'=D(#T@*&1E9FEN960@)D-W9#HZ9V5T8W=D*2`_($-W9#HZ
M9V5T8W=D*"D*("`@("`@("`@("`@("`@(#H@*"AD969I;F5D("97:6XS,CHZ
M1V5T0W=D*2`_(%=I;C,R.CI'971#=V0H*2`Z(&!P=V1@*3L*("`@(&-H;VUP
M*"1P=V0I.PH@("`@)'!R;V=N86UE(#U^(',O7B@_/5PN7"X_7%$D0V]N9FEG
M>U]D96QI;7U<12DO)'!W9"1#;VYF:6=[7V1E;&EM?2\["@H@("`@)$5.5GM0
M05)?4%)/1TY!345](#T@)'!R;V=N86UE.PI]"@IS=6(@7W!A<E]I;FET7V5N
M=B!["B`@("!I9B`H("1%3E9[4$%27TE.251)04Q)6D5$?2LK(#T](#$@*2![
M"B`@("`@("`@<F5T=7)N.PH@("`@?2!E;'-E('L*("`@("`@("`D14Y6>U!!
M4E])3DE424%,25I%1'T@/2`R.PH@("`@?0H*("`@(&9O<B`H<7<H(%-005=.
M140@5$5-4"!#3$5!3B!$14)51R!#04-(12!04D]'3D%-12!!4D=#($%21U9?
M,"`I("D@>PH@("`@("`@(&1E;&5T92`D14Y6>R=005)?)RXD7WT["B`@("!]
M"B`@("!F;W(@*'%W+R!435!$25(@5$5-4"!#3$5!3B!$14)51R`O*2!["B`@
M("`@("`@)$5.5GLG4$%27R<N)%]](#T@)$5.5GLG4$%27T=,3T)!3%\G+B1?
M?2!I9B!E>&ES=',@)$5.5GLG4$%27T=,3T)!3%\G+B1??3L*("`@('T*"B`@
M("!M>2`D<&%R7V-L96%N(#T@(E]?14Y67U!!4E]#3$5!3E]?("`@("`@("`@
M("`@("`@(CL*"B`@("!I9B`H)$5.5GM005)?5$5-4'TI('L*("`@("`@("!D
M96QE=&4@)$5.5GM005)?0TQ%04Y].PH@("`@?0H@("`@96QS:68@*"%E>&ES
M=',@)$5.5GM005)?1TQ/0D%,7T-,14%.?2D@>PH@("`@("`@(&UY("1V86QU
M92`]('-U8G-T<B@D<&%R7V-L96%N+"`Q,B`K(&QE;F=T:"@B0TQ%04XB*2D[
M"B`@("`@("`@)$5.5GM005)?0TQ%04Y](#T@)#$@:68@)'9A;'5E(#U^("]>
M4$%27T-,14%./2A<4RLI+SL*("`@('T*?0H*<W5B(&]U=',@>PH@("`@<F5T
M=7)N(&EF("1Q=6EE=#L*("`@(&EF("@D;&]G9F@I('L*("`@("`@("!P<FEN
M="`D;&]G9F@@(D!?7&XB.PH@("`@?0H@("`@96QS92!["B`@("`@("`@<')I
M;G0@(D!?7&XB.PH@("`@?0I]"@IS=6(@:6YI=%]I;F,@>PH@("`@<F5Q=6ER
M92!#;VYF:6<["B`@("!P=7-H($!)3D,L(&=R97`@9&5F:6YE9"P@;6%P("1#
M;VYF:6<Z.D-O;F9I9WLD7WTL('%W*`H@("`@("`@(&%R8VAL:6)E>'`@<')I
M=FQI8F5X<"!S:71E87)C:&5X<"!S:71E;&EB97AP"B`@("`@("`@=F5N9&]R
M87)C:&5X<"!V96YD;W)L:6)E>'`*("`@("D["GT*"B,C(R,C(R,C(R,C(R,C
M(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C
M(R,C(R,C(R,C(R,C(PHC(%1H92!M86EN('!A8VMA9V4@9F]R('-C<FEP="!E
M>&5C=71I;VX*"G!A8VMA9V4@;6%I;CL*"G)E<75I<F4@4$%2.PIU;G-H:69T
M($!)3D,L(%PF4$%2.CIF:6YD7W!A<CL*4$%2+3YI;7!O<G0H0'!A<E]A<F=S
M*3L*"F1I92!Q<2AP87(N<&PZ($-A;B=T(&]P96X@<&5R;"!S8W)I<'0@(B1P
M<F]G;F%M92(Z($YO('-U8V@@9FEL92!O<B!D:7)E8W1O<GE<;BD*("`@('5N
M;&5S<R`M92`D<')O9VYA;64["@ID;R`D<')O9VYA;64["D-/4D4Z.F5X:70H
M)#$I(&EF("@D0"`]?B]>7U1+7T58251?7"@H7&0K*5PI+RD["F1I92`D0"!I
M9B`D0#L*"GT["@HD.CI?7T524D]2(#T@)$`@:68@)$`["GT*"D-/4D4Z.F5X
M:70H)#$I(&EF("@D.CI?7T524D]2(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO
M*3L*9&EE("0Z.E]?15)23U(@:68@)#HZ7U]%4E)/4CL*"C$["@HC;&EN92`Q
M,#$R"@I?7T5.1%]?"@````$;`SO(````&````*1Q___D````E'[__Q0!``!4
M?___1`$``'1___]D`0``U'___Y`!```$@O__O`$``'2#___\`0``1(3__S0"
M```DAO__9`(``&2&__^$`@``U(;__Z0"``"DA___U`(``+2'___T`@``I(G_
M_R0#``#4B?__1`,``,2*__]X`P``9(S__Z0#``"DC/__S`,``,2,___L`P``
MU(W__QP$``#DE___4`0``%2=__^`!```Q)W__[0$```DGO__U`0``!0`````
M`````7I2``%\"`$;#`0$B`$``"P````<````N'#__^4,````00X(A0)"#05+
M@P6&!(<#`],,PT'&0<=!Q0P$!````"P```!,````>'W__[0`````00X(A0)"
M#05)@P5/AP.&!$L*#03'QL-!Q0X$00L``!P```!\````"'[__Q$`````00X(
MA0)"#05-Q0P$!```*````)P````(?O__40````!!#@B%`D(-!4.&`T:#!`)"
MPT'&0<4,!`0````H````R````#Q^__\H`@```$$."(4"0@T%38,$A@,#%0+#
M0<9!Q0P$!````#P```#T````0(#__VH!````00X(A0)"#05#AP--@P6&!$T*
MPT'&0<=!Q0P$!$4+`P@!"L-!QD''00P$!,5%"P`T````-`$``'"!___+````
M`$$."(4"0@T%0X8#0X,$`D$*PT'&0<4,!`1$"P)XPT'&00P$!,4``"P```!L
M`0``"(+__]\!````00X(A0)"#05$A@2'`T6#!0)1"L-!QD''0<4,!`1("QP`
M``"<`0``N(/__S\`````00X(A0)"#05[Q0P$!```'````+P!``#8@___;0``
M``!!#@B%`D(-!0)IQ0P$!``L````W`$``"B$___$`````$$."(4"0@T%88<#
MA@2#!0)0"@T$Q\;#0<4.!$,+```<````#`(``,B$__\-`````$$."(4"0@T%
M1<4,!`0``"P````L`@``N(3__^D!````00X(A0)"#05-@P6&!(<#`E@*PT'&
M0<=!Q0P$!$$+`!P```!<`@``>(;__R(`````00X(A0)"#05>Q0P$!```,```
M`'P"``"(AO__[`````!!#@B%`D(-!4B#`P)'"L-!Q0P$!$4+80K#0<4,!`1&
M"P```"@```"P`@``1(?__YT!````00X(A0)"#04"888$AP,"ZPK&0<=!Q0P$
M!$<+)````-P"``"XB/__0`````!!#@B%`D(-!4\*Q0P$!$8+9PP$!,4``!P`
M```$`P``T(C__R``````00X(A0)"#05<Q0P$!```+````"0#``#0B/__!`$`
M``!!#@B%`D(-!46&!(<#1H,%`G\*PT'&0<=!Q0P$!$@+,````%0#``"PB?__
M#0H```!!#@B%`D(-!0*F@P6&!(<#`]H""L-!QD''0<4,!`1""P```"P```"(
M`P``C)/__VH%````00X(A0)"#05<@P6&!(<#`]\""L-!QD''0<4,!`1'"S``
M``"X`P``S)C__VP`````00X(A0)"#05)@P2&`P)/"L-!QD'%#`0$00M'PT'&
M0<4,!`0<````[`,```B9__]=`````$$."(4"0@T%`EG%#`0$`#P````,!```
M2)G__R`"````00X(A0)"#05=$`,'=0`)\!HX'!`&!W4`"?`:-!P#EP$*PT'&
M0@T$0<4.!$4+````````_____P````#_____```````````!`````0````$`
M``"Y`@```0```,@"```!````U`(```$```#?`@```0```.D"```!````]P(`
M``$````$`P```0```%,#```/````R00``!T```#)!```#````-20!`@-````
M;,8$"/7^_V^,@00(!0```+R'!`@&````[($$"`H````=!0``"P```!`````5
M``````````,```"4.P4(`@```(@"```4````$0```!<```!,C@0($0```#2.
M!`@2````&````!,````(````_O__;Y2-!`C___]O`@```/#__V_:C`0(````
M````````````````````````````````````````````````````````````
M`````'@Z!0@``````````!J1!`@JD00(.I$$"$J1!`A:D00(:I$$"'J1!`B*
MD00(FI$$"*J1!`BZD00(RI$$"-J1!`CJD00(^I$$"`J2!`@:D@0(*I($"#J2
M!`A*D@0(6I($"&J2!`AZD@0(BI($")J2!`BJD@0(NI($",J2!`C:D@0(ZI($
M"/J2!`@*DP0(&I,$""J3!`@ZDP0(2I,$"%J3!`AJDP0(>I,$"(J3!`B:DP0(
MJI,$"+J3!`C*DP0(VI,$".J3!`CZDP0("I0$"!J4!`@JE`0(.I0$"$J4!`A:
ME`0(:I0$"'J4!`B*E`0(FI0$"*J4!`BZE`0(RI0$"-J4!`CJE`0(^I0$"`J5
M!`@:E00(*I4$"#J5!`A*E00(6I4$"&J5!`AZE00(BI4$")J5!`BJE00(NI4$
M",J5!`C:E00(ZI4$"/J5!`@*E@0(&I8$"`````#_____2,D$".E;``!'0T,Z
M("A'3E4I(#0N-2XQ(#(P,3`P.3`W("A2960@2&%T(#0N-2XQ+3,I`$=#0SH@
M*$=.52D@-"XU+C$@,C`Q,#`Y,C0@*%)E9"!(870@-"XU+C$M-"D``"YS:'-T
M<G1A8@`N:6YT97)P`"YN;W1E+D%"22UT86<`+FYO=&4N9VYU+F)U:6QD+6ED
M`"YG;G4N:&%S:``N9'EN<WEM`"YD>6YS='(`+F=N=2YV97)S:6]N`"YG;G4N
M=F5R<VEO;E]R`"YR96PN9'EN`"YR96PN<&QT`"YI;FET`"YT97AT`"YF:6YI
M`"YR;V1A=&$`+F5H7V9R86UE7VAD<@`N96A?9G)A;64`+F-T;W)S`"YD=&]R
M<P`N:F-R`"YD>6YA;6EC`"YG;W0`+F=O="YP;'0`+F1A=&$`+F)S<P`N8V]M
M;65N=```````````````````````````````````````````````````````
M"P````$````"````-($$"#0!```3```````````````!`````````!,````'
M`````@```$B!!`A(`0``(```````````````!``````````A````!P````(`
M``!H@00(:`$``"0```````````````0`````````-````/;__V\"````C($$
M"(P!``!@````!0`````````$````!````#X````+`````@```.R!!`CL`0``
MT`4```8````!````!````!````!&`````P````(```"\AP0(O`<``!T%````
M``````````$`````````3@```/___V\"````VHP$"-H,``"Z````!0``````
M```"`````@```%L```#^__]O`@```)2-!`B4#0``H`````8````"````!```
M``````!J````"0````(````TC@0(-`X``!@````%``````````0````(````
M<P````D````"````3(X$"$P.``"(`@``!0````P````$````"````'P````!
M````!@```-20!`C4$```,```````````````!`````````!W`````0````8`
M```$D00(!!$``"`%``````````````0````$````@@````$````&````,)8$
M"#`6```\,``````````````0`````````(@````!````!@```&S&!`AL1@``
M'```````````````!`````````".`````0````(```"@Q@0(H$8``*I>````
M`````````"``````````E@````$````"````3"4%"$RE``#,````````````
M```$`````````*0````!`````@```!@F!0@8I@``3`0`````````````!```
M``````"N`````0````,```!D.@4(9*H```@```````````````0`````````
MM0````$````#````;#H%"&RJ```(```````````````$`````````+P````!
M`````P```'0Z!0ATJ@``!```````````````!`````````#!````!@````,`
M``!X.@4(>*H``!@!```&``````````0````(````R@````$````#````D#L%
M")"K```$```````````````$````!````,\````!`````P```)0[!0B4JP``
M4`$`````````````!`````0```#8`````0````,```#D/`4(Y*P``!``````
M``````````0`````````W@````@````#`````#T%"/2L``!`$```````````
M```@`````````.,````!````,`````````#TK```6````````````````0``
M``$````!`````P``````````````3*T``.P```````````````$`````````
